@@ -42,7 +42,11 @@ class QProcessEnvironment;
 
 struct QBtCommandLineParameters
 {
-    bool showHelp, relativeFastresumePaths, portableMode, skipChecking, sequential, firstLastPiecePriority;
+    bool showHelp;
+    bool relativeFastresumePaths;
+    bool skipChecking;
+    bool sequential;
+    bool firstLastPiecePriority;
 #if !defined(Q_OS_WIN) || defined(DISABLE_GUI)
     bool showVersion;
 #endif
@@ -52,11 +56,16 @@ struct QBtCommandLineParameters
     bool shouldDaemonize;
 #endif
     int webUiPort;
-    TriStateBool addPaused, skipDialog;
+    TriStateBool addPaused;
+    TriStateBool skipDialog;
     QStringList torrents;
-    QString profileDir, configurationName, savePath, category, unknownParameter;
+    QString profileDir;
+    QString configurationName;
+    QString savePath;
+    QString category;
+    QString unknownParameter;
 
-    explicit QBtCommandLineParameters(const QProcessEnvironment&);
+    explicit QBtCommandLineParameters(const QProcessEnvironment &);
     QStringList paramList() const;
 };
 
