@@ -27,10 +27,22 @@
  * exception statement from your version.
  */
 
+#include <QtGlobal>
+
+#include <csignal>
 #include <cstdlib>
+#include <memory>
+
+#if defined(Q_OS_UNIX)
+#include <sys/resource.h>
+#endif
+#if !defined Q_OS_WIN && !defined Q_OS_HAIKU
+#include <unistd.h>
+#elif defined Q_OS_WIN && defined DISABLE_GUI
+#include <io.h>
+#endif
 
 #include <QDebug>
-#include <QScopedPointer>
 #include <QThread>
 
 #ifndef DISABLE_GUI
@@ -41,6 +53,7 @@
 #include <QPen>
 #include <QPushButton>
 #include <QSplashScreen>
+#include <QTimer>
 
 #ifdef QBT_STATIC_QT
 #include <QtPlugin>
@@ -50,35 +63,36 @@ Q_IMPORT_PLUGIN(QICOPlugin)
 #else
 // NoGUI-only includes
 #include <cstdio>
-#ifdef Q_OS_UNIX
-#include "unistd.h"
-#endif
 #endif // DISABLE_GUI
 
-#include <signal.h>
 #ifdef STACKTRACE
 #ifdef Q_OS_UNIX
 #include "stacktrace.h"
 #else
 #include "stacktrace_win.h"
+#ifndef DISABLE_GUI
 #include "stacktracedialog.h"
+#endif // DISABLE_GUI
 #endif // Q_OS_UNIX
 #endif //STACKTRACE
 
 #include "base/preferences.h"
 #include "base/profile.h"
-#include "base/utils/misc.h"
 #include "application.h"
 #include "cmdoptions.h"
 #include "upgrade.h"
 
+#ifndef DISABLE_GUI
+#include "gui/utils.h"
+#endif
+
 // Signal handlers
 void sigNormalHandler(int signum);
 #ifdef STACKTRACE
 void sigAbnormalHandler(int signum);
 #endif
 // sys_signame[] is only defined in BSD
-const char *sysSigName[] = {
+const char *const sysSigName[] = {
 #if defined(Q_OS_WIN)
     "", "", "SIGINT", "", "SIGILL", "", "SIGABRT_COMPAT", "", "SIGFPE", "",
     "", "SIGSEGV", "", "", "", "SIGTERM", "", "", "", "",
@@ -92,7 +106,7 @@ const char *sysSigName[] = {
 #endif
 };
 
-#if !defined Q_OS_WIN && !defined Q_OS_HAIKU
+#if !(defined Q_OS_WIN && !defined DISABLE_GUI) && !defined Q_OS_HAIKU
 void reportToUser(const char *str);
 #endif
 
@@ -104,37 +118,40 @@ void displayBadArgMessage(const QString &message);
 void showSplashScreen();
 #endif  // DISABLE_GUI
 
+#if defined(Q_OS_UNIX)
+void adjustFileDescriptorLimit();
+#endif
+
 // Main
 int main(int argc, char *argv[])
 {
+#if defined(Q_OS_UNIX)
+    adjustFileDescriptorLimit();
+#endif
+
     // We must save it here because QApplication constructor may change it
     bool isOneArg = (argc == 2);
 
-#ifdef Q_OS_MAC
-    // On macOS 10.12 Sierra, Apple changed the behaviour of CFPreferencesSetValue() https://bugreports.qt.io/browse/QTBUG-56344
-    // Due to this, we have to move from native plist to IniFormat
-    macMigratePlists();
+#if !defined(DISABLE_GUI) && (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+    // Attribute Qt::AA_EnableHighDpiScaling must be set before QCoreApplication is created
+    if (qgetenv("QT_ENABLE_HIGHDPI_SCALING").isEmpty() && qgetenv("QT_AUTO_SCREEN_SCALE_FACTOR").isEmpty())
+        Application::setAttribute(Qt::AA_EnableHighDpiScaling, true);
+    // HighDPI scale factor policy must be set before QGuiApplication is created
+    if (qgetenv("QT_SCALE_FACTOR_ROUNDING_POLICY").isEmpty())
+        Application::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
 #endif
 
     try {
         // Create Application
-        QString appId = QLatin1String("qBittorrent-") + Utils::Misc::getUserIDString();
-        QScopedPointer<Application> app(new Application(appId, argc, argv));
-
-#ifndef DISABLE_GUI
-        // after the application object creation because we need a profile to be set already
-        // for the migration
-        migrateRSS();
-#endif
+        auto app = std::make_unique<Application>(argc, argv);
 
         const QBtCommandLineParameters params = app->commandLineArgs();
-
         if (!params.unknownParameter.isEmpty()) {
             throw CommandLineParameterError(QObject::tr("%1 is an unknown command line parameter.",
                                                         "--random-parameter is an unknown command line parameter.")
                                                         .arg(params.unknownParameter));
         }
-#ifndef Q_OS_WIN
+#if !defined(Q_OS_WIN) || defined(DISABLE_GUI)
         if (params.showVersion) {
             if (isOneArg) {
                 displayVersion();
@@ -157,20 +174,29 @@ int main(int argc, char *argv[])
         if (!qputenv("QBITTORRENT", QBT_VERSION))
             fprintf(stderr, "Couldn't set environment variable...\n");
 
+        const bool firstTimeUser = !Preferences::instance()->getAcceptedLegal();
+        if (firstTimeUser) {
 #ifndef DISABLE_GUI
-        if (!userAgreesWithLegalNotice())
-            return EXIT_SUCCESS;
+            if (!userAgreesWithLegalNotice())
+                return EXIT_SUCCESS;
+
+#elif defined(Q_OS_WIN)
+            if (_isatty(_fileno(stdin))
+                && _isatty(_fileno(stdout))
+                && !userAgreesWithLegalNotice())
+                return EXIT_SUCCESS;
 #else
-        if (!params.shouldDaemonize
-            && isatty(fileno(stdin))
-            && isatty(fileno(stdout))
-            && !userAgreesWithLegalNotice())
-            return EXIT_SUCCESS;
+            if (!params.shouldDaemonize
+                && isatty(fileno(stdin))
+                && isatty(fileno(stdout))
+                && !userAgreesWithLegalNotice())
+                return EXIT_SUCCESS;
 #endif
+        }
 
         // Check if qBittorrent is already running for this user
         if (app->isRunning()) {
-#ifdef DISABLE_GUI
+#if defined(DISABLE_GUI) && !defined(Q_OS_WIN)
             if (params.shouldDaemonize) {
                 throw CommandLineParameterError(QObject::tr("You cannot use %1: qBittorrent is already running for this user.")
                                      .arg(QLatin1String("-d (or --daemon)")));
@@ -198,13 +224,13 @@ int main(int argc, char *argv[])
         // 3. https://bugreports.qt.io/browse/QTBUG-46015
 
         qputenv("QT_BEARER_POLL_TIMEOUT", QByteArray::number(-1));
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0))
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)) && !defined(DISABLE_GUI)
         // this is the default in Qt6
         app->setAttribute(Qt::AA_DisableWindowContextHelpButton);
 #endif
 #endif // Q_OS_WIN
 
-#if defined(Q_OS_MAC)
+#if defined(Q_OS_MACOS)
         // Since Apple made difficult for users to set PATH, we set here for convenience.
         // Users are supposed to install Homebrew Python for search function.
         // For more info see issue #5571.
@@ -216,18 +242,29 @@ int main(int argc, char *argv[])
         app->setAttribute(Qt::AA_DontShowIconsInMenus);
 #endif
 
+        if (!firstTimeUser) {
+            handleChangedDefaults(DefaultPreferencesMode::Legacy);
+
 #ifndef DISABLE_GUI
-        if (!upgrade()) return EXIT_FAILURE;
+            if (!upgrade()) return EXIT_FAILURE;
+#elif defined(Q_OS_WIN)
+            if (!upgrade(_isatty(_fileno(stdin))
+                         && _isatty(_fileno(stdout)))) return EXIT_FAILURE;
 #else
-        if (!upgrade(!params.shouldDaemonize
-                     && isatty(fileno(stdin))
-                     && isatty(fileno(stdout)))) return EXIT_FAILURE;
+            if (!upgrade(!params.shouldDaemonize
+                         && isatty(fileno(stdin))
+                         && isatty(fileno(stdout)))) return EXIT_FAILURE;
 #endif
-#ifdef DISABLE_GUI
+        }
+        else {
+            handleChangedDefaults(DefaultPreferencesMode::Current);
+        }
+
+#if defined(DISABLE_GUI) && !defined(Q_OS_WIN)
         if (params.shouldDaemonize) {
             app.reset(); // Destroy current application
             if (daemon(1, 0) == 0) {
-                app.reset(new Application(appId, argc, argv));
+                app = std::make_unique<Application>(argc, argv);
                 if (app->isRunning()) {
                     // Another instance had time to start.
                     return EXIT_FAILURE;
@@ -238,7 +275,7 @@ int main(int argc, char *argv[])
                 return EXIT_FAILURE;
             }
         }
-#else
+#elif !defined(DISABLE_GUI)
         if (!(params.noSplash || Preferences::instance()->isSplashScreenDisabled()))
             showSplashScreen();
 #endif
@@ -252,18 +289,23 @@ int main(int argc, char *argv[])
 
         return app->exec(params.paramList());
     }
-    catch (CommandLineParameterError &er) {
+    catch (const CommandLineParameterError &er) {
         displayBadArgMessage(er.messageForUser());
         return EXIT_FAILURE;
     }
 }
 
-#if !defined Q_OS_WIN && !defined Q_OS_HAIKU
+#if !(defined Q_OS_WIN && !defined DISABLE_GUI) && !defined Q_OS_HAIKU
 void reportToUser(const char *str)
 {
     const size_t strLen = strlen(str);
+#ifndef Q_OS_WIN
     if (write(STDERR_FILENO, str, strLen) < static_cast<ssize_t>(strLen)) {
-        auto dummy = write(STDOUT_FILENO, str, strLen);
+        const auto dummy = write(STDOUT_FILENO, str, strLen);
+#else
+    if (_write(STDERR_FILENO, str, strLen) < static_cast<ssize_t>(strLen)) {
+        const auto dummy = _write(STDOUT_FILENO, str, strLen);
+#endif
         Q_UNUSED(dummy);
     }
 }
@@ -271,7 +313,7 @@ void reportToUser(const char *str)
 
 void sigNormalHandler(int signum)
 {
-#if !defined Q_OS_WIN && !defined Q_OS_HAIKU
+#if !(defined Q_OS_WIN && !defined DISABLE_GUI) && !defined Q_OS_HAIKU
     const char msg1[] = "Catching signal: ";
     const char msg2[] = "\nExiting cleanly\n";
     reportToUser(msg1);
@@ -286,7 +328,7 @@ void sigNormalHandler(int signum)
 void sigAbnormalHandler(int signum)
 {
     const char *sigName = sysSigName[signum];
-#if !defined Q_OS_WIN && !defined Q_OS_HAIKU
+#if !(defined Q_OS_WIN && !defined DISABLE_GUI) && !defined Q_OS_HAIKU
     const char msg[] = "\n\n*************************************************************\n"
         "Please file a bug report at http://bug.qbittorrent.org and provide the following information:\n\n"
         "qBittorrent version: " QBT_VERSION "\n\n"
@@ -297,7 +339,7 @@ void sigAbnormalHandler(int signum)
     print_stacktrace();  // unsafe
 #endif
 
-#if defined Q_OS_WIN
+#if defined Q_OS_WIN && !defined DISABLE_GUI
     StacktraceDialog dlg;  // unsafe
     dlg.setStacktraceString(QLatin1String(sigName), straceWin::getBacktrace());
     dlg.exec();
@@ -313,10 +355,14 @@ void showSplashScreen()
 {
     QPixmap splashImg(":/icons/skin/splash.png");
     QPainter painter(&splashImg);
-    QString version = QBT_VERSION;
+    const QString version = QBT_VERSION;
     painter.setPen(QPen(Qt::white));
     painter.setFont(QFont("Arial", 22, QFont::Black));
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 11, 0))
+    painter.drawText(224 - painter.fontMetrics().horizontalAdvance(version), 270, version);
+#else
     painter.drawText(224 - painter.fontMetrics().width(version), 270, version);
+#endif
     QSplashScreen *splash = new QSplashScreen(splashImg);
     splash->show();
     QTimer::singleShot(1500, splash, &QObject::deleteLater);
@@ -331,12 +377,12 @@ void displayVersion()
 
 void displayBadArgMessage(const QString &message)
 {
-    QString help = QObject::tr("Run application with -h option to read about command line parameters.");
-#ifdef Q_OS_WIN
+    const QString help = QObject::tr("Run application with -h option to read about command line parameters.");
+#if defined(Q_OS_WIN) && !defined(DISABLE_GUI)
     QMessageBox msgBox(QMessageBox::Critical, QObject::tr("Bad command line"),
                        message + QLatin1Char('\n') + help, QMessageBox::Ok);
     msgBox.show(); // Need to be shown or to moveToCenter does not work
-    msgBox.move(Utils::Misc::screenCenter(&msgBox));
+    msgBox.move(Utils::Gui::screenCenter(&msgBox));
     msgBox.exec();
 #else
     const QString errMsg = QObject::tr("Bad command line: ") + '\n'
@@ -349,17 +395,16 @@ void displayBadArgMessage(const QString &message)
 bool userAgreesWithLegalNotice()
 {
     Preferences *const pref = Preferences::instance();
-    if (pref->getAcceptedLegal()) // Already accepted once
-        return true;
+    Q_ASSERT(!pref->getAcceptedLegal());
 
 #ifdef DISABLE_GUI
-    const QString eula = QString("\n*** %1 ***\n").arg(QObject::tr("Legal Notice"))
+    const QString eula = QString::fromLatin1("\n*** %1 ***\n").arg(QObject::tr("Legal Notice"))
         + QObject::tr("qBittorrent is a file sharing program. When you run a torrent, its data will be made available to others by means of upload. Any content you share is your sole responsibility.") + "\n\n"
         + QObject::tr("No further notices will be issued.") + "\n\n"
         + QObject::tr("Press %1 key to accept and continue...").arg("'y'") + '\n';
     printf("%s", qUtf8Printable(eula));
 
-    char ret = getchar(); // Read pressed key
+    const char ret = getchar(); // Read pressed key
     if ((ret == 'y') || (ret == 'Y')) {
         // Save the answer
         pref->setAcceptedLegal(true);
@@ -370,9 +415,9 @@ bool userAgreesWithLegalNotice()
     msgBox.setText(QObject::tr("qBittorrent is a file sharing program. When you run a torrent, its data will be made available to others by means of upload. Any content you share is your sole responsibility.\n\nNo further notices will be issued."));
     msgBox.setWindowTitle(QObject::tr("Legal notice"));
     msgBox.addButton(QObject::tr("Cancel"), QMessageBox::RejectRole);
-    QAbstractButton *agreeButton = msgBox.addButton(QObject::tr("I Agree"), QMessageBox::AcceptRole);
+    const QAbstractButton *agreeButton = msgBox.addButton(QObject::tr("I Agree"), QMessageBox::AcceptRole);
     msgBox.show(); // Need to be shown or to moveToCenter does not work
-    msgBox.move(Utils::Misc::screenCenter(&msgBox));
+    msgBox.move(Utils::Gui::screenCenter(&msgBox));
     msgBox.exec();
     if (msgBox.clickedButton() == agreeButton) {
         // Save the answer
@@ -383,3 +428,16 @@ bool userAgreesWithLegalNotice()
 
     return false;
 }
+
+#if defined(Q_OS_UNIX)
+void adjustFileDescriptorLimit()
+{
+    rlimit limit {};
+
+    if (getrlimit(RLIMIT_NOFILE, &limit) != 0)
+        return;
+
+    limit.rlim_cur = limit.rlim_max;
+    setrlimit(RLIMIT_NOFILE, &limit);
+}
+#endif
