@@ -28,4 +28,11 @@
 
 #pragma once
 
+enum class DefaultPreferencesMode
+{
+    Legacy,
+    Current
+};
+
+void handleChangedDefaults(DefaultPreferencesMode mode);
 bool upgrade(bool ask = true);
