@@ -31,33 +31,32 @@
 #include <libtorrent/bencode.hpp>
 #include <libtorrent/error_code.hpp>
 #include <libtorrent/magnet_uri.hpp>
+#include <libtorrent/sha1_hash.hpp>
 
-#include <QByteArray>
 #include <QRegularExpression>
-#include <QStringList>
+#include <QUrl>
 
-#include "base/utils/string.h"
+#include "infohash.h"
 
 namespace
 {
-    QString bcLinkToMagnet(QString bcLink)
+    bool isBitTorrentInfoHash(const QString &string)
     {
-        QByteArray rawBc = bcLink.toUtf8();
-        rawBc = rawBc.mid(8); // skip bc://bt/
-        rawBc = QByteArray::fromBase64(rawBc); // Decode base64
-        // Format is now AA/url_encoded_filename/size_bytes/info_hash/ZZ
-        QStringList parts = QString(rawBc).split('/');
-        if (parts.size() != 5) return QString();
+        // There are 2 represenations for BitTorrent info hash:
+        // 1. 40 chars hex-encoded string
+        //      == 20 (SHA-1 length in bytes) * 2 (each byte maps to 2 hex characters)
+        // 2. 32 chars Base32 encoded string
+        //      == 20 (SHA-1 length in bytes) * 1.6 (the efficiency of Base32 encoding)
+        const int SHA1_HEX_SIZE = BitTorrent::InfoHash::length() * 2;
+        const int SHA1_BASE32_SIZE = BitTorrent::InfoHash::length() * 1.6;
 
-        QString filename = parts.at(1);
-        QString hash = parts.at(3);
-        QString magnet = "magnet:?xt=urn:btih:" + hash;
-        magnet += "&dn=" + filename;
-        return magnet;
+        return ((((string.size() == SHA1_HEX_SIZE))
+                && !string.contains(QRegularExpression(QLatin1String("[^0-9A-Fa-f]"))))
+            || ((string.size() == SHA1_BASE32_SIZE)
+                && !string.contains(QRegularExpression(QLatin1String("[^2-7A-Za-z]")))));
     }
 }
 
-namespace libt = libtorrent;
 using namespace BitTorrent;
 
 MagnetUri::MagnetUri(const QString &source)
@@ -66,28 +65,24 @@ MagnetUri::MagnetUri(const QString &source)
 {
     if (source.isEmpty()) return;
 
-    if (source.startsWith("bc://bt/", Qt::CaseInsensitive)) {
-        qDebug("Creating magnet link from bc link");
-        m_url = bcLinkToMagnet(source);
-    }
-    else if (((source.size() == 40) && !source.contains(QRegularExpression("[^0-9A-Fa-f]")))
-             || ((source.size() == 32) && !source.contains(QRegularExpression("[^2-7A-Za-z]")))) {
-        m_url = "magnet:?xt=urn:btih:" + source;
-    }
+    if (isBitTorrentInfoHash(source))
+        m_url = QLatin1String("magnet:?xt=urn:btih:") + source;
 
-    libt::error_code ec;
-    libt::parse_magnet_uri(m_url.toUtf8().constData(), m_addTorrentParams, ec);
+    lt::error_code ec;
+    lt::parse_magnet_uri(m_url.toStdString(), m_addTorrentParams, ec);
     if (ec) return;
 
     m_valid = true;
     m_hash = m_addTorrentParams.info_hash;
     m_name = QString::fromStdString(m_addTorrentParams.name);
 
+    m_trackers.reserve(m_addTorrentParams.trackers.size());
     for (const std::string &tracker : m_addTorrentParams.trackers)
-        m_trackers.append(QString::fromStdString(tracker));
+        m_trackers.append(lt::announce_entry {tracker});
 
+    m_urlSeeds.reserve(m_addTorrentParams.url_seeds.size());
     for (const std::string &urlSeed : m_addTorrentParams.url_seeds)
-        m_urlSeeds.append(QUrl(urlSeed.c_str()));
+        m_urlSeeds.append(QUrl(QString::fromStdString(urlSeed)));
 }
 
 bool MagnetUri::isValid() const
@@ -105,12 +100,12 @@ QString MagnetUri::name() const
     return m_name;
 }
 
-QList<TrackerEntry> MagnetUri::trackers() const
+QVector<TrackerEntry> MagnetUri::trackers() const
 {
     return m_trackers;
 }
 
-QList<QUrl> MagnetUri::urlSeeds() const
+QVector<QUrl> MagnetUri::urlSeeds() const
 {
     return m_urlSeeds;
 }
@@ -120,7 +115,7 @@ QString MagnetUri::url() const
     return m_url;
 }
 
-libtorrent::add_torrent_params MagnetUri::addTorrentParams() const
+lt::add_torrent_params MagnetUri::addTorrentParams() const
 {
     return m_addTorrentParams;
 }
