@@ -34,6 +34,6 @@
 class RuntimeError : public std::runtime_error
 {
 public:
-    explicit RuntimeError(const QString &message = "");
+    explicit RuntimeError(const QString &message = {});
     QString message() const;
 };
