@@ -30,6 +30,8 @@
 
 #include "requestparser.h"
 
+#include <algorithm>
+
 #include <QDebug>
 #include <QRegularExpression>
 #include <QStringList>
@@ -199,7 +201,9 @@ bool RequestParser::parseRequestLine(const QString &line)
             const QByteArray nameComponent = midView(param, 0, eqCharPos);
             const QByteArray valueComponent = midView(param, (eqCharPos + 1));
             const QString paramName = QString::fromUtf8(QByteArray::fromPercentEncoding(nameComponent).replace('+', ' '));
-            const QByteArray paramValue = QByteArray::fromPercentEncoding(valueComponent).replace('+', ' ');
+            const QByteArray paramValue = valueComponent.isNull()
+                ? ""
+                : QByteArray::fromPercentEncoding(valueComponent).replace('+', ' ');
 
             m_request.query[paramName] = paramValue;
         }
@@ -251,7 +255,7 @@ bool RequestParser::parsePostMessage(const QByteArray &data)
 
         // split data by "dash-boundary"
         const QByteArray dashDelimiter = QByteArray("--") + delimiter + CRLF;
-        QList<QByteArray> multipart = splitToViews(data, dashDelimiter, QString::SkipEmptyParts);
+        QVector<QByteArray> multipart = splitToViews(data, dashDelimiter, QString::SkipEmptyParts);
         if (multipart.isEmpty()) {
             qWarning() << Q_FUNC_INFO << "multipart empty";
             return false;
@@ -261,12 +265,10 @@ bool RequestParser::parsePostMessage(const QByteArray &data)
         const QByteArray endDelimiter = QByteArray("--") + delimiter + QByteArray("--") + CRLF;
         multipart.push_back(viewWithoutEndingWith(multipart.takeLast(), endDelimiter));
 
-        for (const auto &part : multipart) {
-            if (!parseFormData(part))
-                return false;
-        }
-
-        return true;
+        return std::all_of(multipart.cbegin(), multipart.cend(), [this](const QByteArray &part)
+        {
+            return this->parseFormData(part);
+        });
     }
 
     qWarning() << Q_FUNC_INFO << "unknown content type:" << contentType;
@@ -275,7 +277,7 @@ bool RequestParser::parsePostMessage(const QByteArray &data)
 
 bool RequestParser::parseFormData(const QByteArray &data)
 {
-    const QList<QByteArray> list = splitToViews(data, EOH, QString::KeepEmptyParts);
+    const QVector<QByteArray> list = splitToViews(data, EOH, QString::KeepEmptyParts);
 
     if (list.size() != 2) {
         qWarning() << Q_FUNC_INFO << "multipart/form-data format error";
