@@ -30,9 +30,9 @@
 
 using namespace Http;
 
-void ResponseBuilder::status(uint code, const QString &text)
+void ResponseBuilder::status(const uint code, const QString &text)
 {
-    m_response.status = ResponseStatus(code, text);
+    m_response.status = {code, text};
 }
 
 void ResponseBuilder::header(const QString &name, const QString &value)
