@@ -32,50 +32,39 @@
 #define HTTP_SERVER_H
 
 #include <QSet>
-#include <QTcpServer>
-
-#ifndef QT_NO_OPENSSL
 #include <QSslCertificate>
-#include <QSslCipher>
 #include <QSslKey>
-#endif
+#include <QTcpServer>
 
 namespace Http
 {
     class IRequestHandler;
     class Connection;
 
-    class Server : public QTcpServer
+    class Server final : public QTcpServer
     {
         Q_OBJECT
         Q_DISABLE_COPY(Server)
 
     public:
-        Server(IRequestHandler *requestHandler, QObject *parent = nullptr);
-        ~Server();
+        explicit Server(IRequestHandler *requestHandler, QObject *parent = nullptr);
 
-#ifndef QT_NO_OPENSSL
-        bool setupHttps(const QByteArray &certificates, const QByteArray &key);
+        bool setupHttps(const QByteArray &certificates, const QByteArray &privateKey);
         void disableHttps();
-#endif
 
     private slots:
         void dropTimedOutConnection();
 
     private:
-        void incomingConnection(qintptr socketDescriptor);
+        void incomingConnection(qintptr socketDescriptor) override;
         void removeConnection(Connection *connection);
 
         IRequestHandler *m_requestHandler;
         QSet<Connection *> m_connections;  // for tracking persistent connections
 
-#ifndef QT_NO_OPENSSL
-        QList<QSslCipher> safeCipherList() const;
-
         bool m_https;
         QList<QSslCertificate> m_certificates;
         QSslKey m_key;
-#endif
     };
 }
 
