@@ -41,15 +41,20 @@ const QString KEY_PASSWORD = SETTINGS_KEY("Password");
 namespace
 {
     inline SettingsStorage *settings() { return SettingsStorage::instance(); }
+}
 
-    inline bool isSameConfig(const Net::ProxyConfiguration &conf1, const Net::ProxyConfiguration &conf2)
-    {
-        return conf1.type == conf2.type
-                && conf1.ip == conf2.ip
-                && conf1.port == conf2.port
-                && conf1.username == conf2.username
-                && conf1.password == conf2.password;
-    }
+bool Net::operator==(const ProxyConfiguration &left, const ProxyConfiguration &right)
+{
+    return (left.type == right.type)
+            && (left.ip == right.ip)
+            && (left.port == right.port)
+            && (left.username == right.username)
+            && (left.password == right.password);
+}
+
+bool Net::operator!=(const ProxyConfiguration &left, const ProxyConfiguration &right)
+{
+    return !(left == right);
 }
 
 using namespace Net;
@@ -79,10 +84,8 @@ void ProxyConfigurationManager::initInstance()
 
 void ProxyConfigurationManager::freeInstance()
 {
-    if (m_instance) {
-        delete m_instance;
-        m_instance = nullptr;
-    }
+    delete m_instance;
+    m_instance = nullptr;
 }
 
 ProxyConfigurationManager *ProxyConfigurationManager::instance()
@@ -97,7 +100,7 @@ ProxyConfiguration ProxyConfigurationManager::proxyConfiguration() const
 
 void ProxyConfigurationManager::setProxyConfiguration(const ProxyConfiguration &config)
 {
-    if (!isSameConfig(config, m_config)) {
+    if (config != m_config) {
         m_config = config;
         settings()->storeValue(KEY_TYPE, static_cast<int>(config.type));
         settings()->storeValue(KEY_IP, config.ip);
@@ -136,17 +139,17 @@ void ProxyConfigurationManager::configureProxy()
     if (!m_isProxyOnlyForTorrents) {
         switch (m_config.type) {
         case ProxyType::HTTP_PW:
-            proxyStrHTTP = QString("http://%1:%2@%3:%4").arg(m_config.username
+            proxyStrHTTP = QString::fromLatin1("http://%1:%2@%3:%4").arg(m_config.username
                 , m_config.password, m_config.ip, QString::number(m_config.port));
             break;
         case ProxyType::HTTP:
-            proxyStrHTTP = QString("http://%1:%2").arg(m_config.ip, QString::number(m_config.port));
+            proxyStrHTTP = QString::fromLatin1("http://%1:%2").arg(m_config.ip, QString::number(m_config.port));
             break;
         case ProxyType::SOCKS5:
-            proxyStrSOCK = QString("%1:%2").arg(m_config.ip, QString::number(m_config.port));
+            proxyStrSOCK = QString::fromLatin1("%1:%2").arg(m_config.ip, QString::number(m_config.port));
             break;
         case ProxyType::SOCKS5_PW:
-            proxyStrSOCK = QString("%1:%2@%3:%4").arg(m_config.username
+            proxyStrSOCK = QString::fromLatin1("%1:%2@%3:%4").arg(m_config.username
                 , m_config.password, m_config.ip, QString::number(m_config.port));
             break;
         default:
