@@ -28,20 +28,20 @@
 
 #include "reverseresolution.h"
 
-#include <boost/asio/ip/tcp.hpp>
-#include <boost/version.hpp>
-
-#include <QDebug>
+#include <QHostAddress>
 #include <QHostInfo>
 #include <QString>
 
-const int CACHE_SIZE = 500;
+const int CACHE_SIZE = 2048;
 
 using namespace Net;
 
-static inline bool isUsefulHostName(const QString &hostname, const QString &ip)
+namespace
 {
-    return (!hostname.isEmpty() && (hostname != ip));
+    bool isUsefulHostName(const QString &hostname, const QHostAddress &ip)
+    {
+        return (!hostname.isEmpty() && (hostname != ip.toString()));
+    }
 }
 
 ReverseResolution::ReverseResolution(QObject *parent)
@@ -52,41 +52,36 @@ ReverseResolution::ReverseResolution(QObject *parent)
 
 ReverseResolution::~ReverseResolution()
 {
-    qDebug("Deleting host name resolver...");
+    // abort on-going lookups instead of waiting them
+    for (auto iter = m_lookups.cbegin(); iter != m_lookups.cend(); ++iter)
+        QHostInfo::abortHostLookup(iter.key());
 }
 
-void ReverseResolution::resolve(const QString &ip)
+void ReverseResolution::resolve(const QHostAddress &ip)
 {
-    if (m_cache.contains(ip)) {
-        const QString &hostname = *m_cache.object(ip);
-        qDebug() << "Resolved host name using cache: " << ip << " -> " << hostname;
-        if (isUsefulHostName(hostname, ip))
-            emit ipResolved(ip, hostname);
-    }
-    else {
-        // Actually resolve the ip
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 9, 0))
-        m_lookups.insert(QHostInfo::lookupHost(ip, this, &ReverseResolution::hostResolved), ip);
-#else
-        m_lookups.insert(QHostInfo::lookupHost(ip, this, SLOT(hostResolved(QHostInfo))), ip);
-#endif
+    const QString *hostname = m_cache.object(ip);
+    if (hostname) {
+        emit ipResolved(ip, *hostname);
+        return;
     }
+
+    // do reverse lookup: IP -> hostname
+    const int lookupId = QHostInfo::lookupHost(ip.toString(), this, &ReverseResolution::hostResolved);
+    m_lookups.insert(lookupId, ip);
 }
 
 void ReverseResolution::hostResolved(const QHostInfo &host)
 {
-    const QString ip = m_lookups.take(host.lookupId());
-    Q_ASSERT(!ip.isNull());
+    const QHostAddress ip = m_lookups.take(host.lookupId());
 
     if (host.error() != QHostInfo::NoError) {
-        qDebug() << "DNS Reverse resolution error: " << host.errorString();
+        emit ipResolved(ip, {});
         return;
     }
 
-    const QString hostname = host.hostName();
-
-    qDebug() << Q_FUNC_INFO << ip << QString("->") << hostname;
+    const QString hostname = isUsefulHostName(host.hostName(), ip)
+        ? host.hostName()
+        : QString();
     m_cache.insert(ip, new QString(hostname));
-    if (isUsefulHostName(hostname, ip))
-        emit ipResolved(ip, hostname);
+    emit ipResolved(ip, hostname);
 }
