@@ -30,13 +30,13 @@
 
 #include <QDataStream>
 #include <QDebug>
-#include <QJsonArray>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonValue>
 #include <QSaveFile>
 #include <QThread>
 #include <QTimer>
+#include <QUrl>
 #include <QVariant>
 #include <QVector>
 
@@ -73,7 +73,7 @@ namespace
     QVector<RSS::AutoDownloadRule> rulesFromJSON(const QByteArray &jsonData)
     {
         QJsonParseError jsonError;
-        QJsonDocument jsonDoc = QJsonDocument::fromJson(jsonData, &jsonError);
+        const QJsonDocument jsonDoc = QJsonDocument::fromJson(jsonData, &jsonError);
         if (jsonError.error != QJsonParseError::NoError)
             throw RSS::ParsingError(jsonError.errorString());
 
@@ -100,7 +100,7 @@ QPointer<AutoDownloader> AutoDownloader::m_instance = nullptr;
 
 QString computeSmartFilterRegex(const QStringList &filters)
 {
-    return QString("(?:_|\\b)(?:%1)(?:_|\\b)").arg(filters.join(QString(")|(?:")));
+    return QString::fromLatin1("(?:_|\\b)(?:%1)(?:_|\\b)").arg(filters.join(QString(")|(?:")));
 }
 
 AutoDownloader::AutoDownloader()
@@ -227,7 +227,7 @@ QByteArray AutoDownloader::exportRules(AutoDownloader::RulesFileFormat format) c
     }
 }
 
-void AutoDownloader::importRules(const QByteArray &data, AutoDownloader::RulesFileFormat format)
+void AutoDownloader::importRules(const QByteArray &data, const AutoDownloader::RulesFileFormat format)
 {
     switch (format) {
     case RulesFileFormat::Legacy:
@@ -333,7 +333,7 @@ void AutoDownloader::process()
 
 void AutoDownloader::handleTorrentDownloadFinished(const QString &url)
 {
-    auto job = m_waitingJobs.take(url);
+    const auto job = m_waitingJobs.take(url);
     if (!job) return;
 
     if (Feed *feed = Session::instance()->feedByURL(job->feedURL))
@@ -347,7 +347,7 @@ void AutoDownloader::handleTorrentDownloadFailed(const QString &url)
     // TODO: Re-schedule job here.
 }
 
-void AutoDownloader::handleNewArticle(Article *article)
+void AutoDownloader::handleNewArticle(const Article *article)
 {
     if (!article->isRead() && !article->torrentUrl().isEmpty())
         addJobForArticle(article);
@@ -358,7 +358,7 @@ void AutoDownloader::setRule_impl(const AutoDownloadRule &rule)
     m_rules.insert(rule.name(), rule);
 }
 
-void AutoDownloader::addJobForArticle(Article *article)
+void AutoDownloader::addJobForArticle(const Article *article)
 {
     const QString torrentURL = article->torrentUrl();
     if (m_waitingJobs.contains(torrentURL)) return;
@@ -385,9 +385,10 @@ void AutoDownloader::processJob(const QSharedPointer<ProcessingJob> &job)
         params.savePath = rule.savePath();
         params.category = rule.assignedCategory();
         params.addPaused = rule.addPaused();
+        params.createSubfolder = rule.createSubfolder();
         if (!rule.savePath().isEmpty())
             params.useAutoTMM = TriStateBool::False;
-        auto torrentURL = job->articleData.value(Article::KeyTorrentURL).toString();
+        const auto torrentURL = job->articleData.value(Article::KeyTorrentURL).toString();
         BitTorrent::Session::instance()->addTorrent(torrentURL, params);
 
         if (BitTorrent::MagnetUri(torrentURL).isValid()) {
@@ -434,10 +435,10 @@ void AutoDownloader::loadRules(const QByteArray &data)
 
 void AutoDownloader::loadRulesLegacy()
 {
-    SettingsPtr settings = Profile::instance().applicationSettings(QStringLiteral("qBittorrent-rss"));
+    const SettingsPtr settings = Profile::instance()->applicationSettings(QStringLiteral("qBittorrent-rss"));
     const QVariantHash rules = settings->value(QStringLiteral("download_rules")).toHash();
     for (const QVariant &ruleVar : rules) {
-        auto rule = AutoDownloadRule::fromLegacyDict(ruleVar.toHash());
+        const auto rule = AutoDownloadRule::fromLegacyDict(ruleVar.toHash());
         if (!rule.name().isEmpty())
             insertRule(rule);
     }
@@ -485,7 +486,7 @@ void AutoDownloader::startProcessing()
     connect(Session::instance()->rootFolder(), &Folder::newArticle, this, &AutoDownloader::handleNewArticle);
 }
 
-void AutoDownloader::setProcessingEnabled(bool enabled)
+void AutoDownloader::setProcessingEnabled(const bool enabled)
 {
     if (m_processingEnabled != enabled) {
         m_processingEnabled = enabled;
