@@ -31,14 +31,12 @@
 #include "rss_session.h"
 
 #include <QDebug>
-#include <QDir>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonValue>
 #include <QSaveFile>
 #include <QString>
 #include <QThread>
-#include <QVariantHash>
 
 #include "../asyncfilestorage.h"
 #include "../global.h"
@@ -263,7 +261,7 @@ void Session::load()
     }
 
     QJsonParseError jsonError;
-    QJsonDocument jsonDoc = QJsonDocument::fromJson(itemsFile.readAll(), &jsonError);
+    const QJsonDocument jsonDoc = QJsonDocument::fromJson(itemsFile.readAll(), &jsonError);
     if (jsonError.error != QJsonParseError::NoError) {
         Logger::instance()->addMessage(
                     QString("Couldn't parse RSS Session data from %1. Error: %2")
@@ -298,7 +296,7 @@ void Session::loadFolder(const QJsonObject &jsonObj, Folder *folder)
             const QJsonObject valObj {val.toObject()};
             if (valObj.contains("url")) {
                 if (!valObj["url"].isString()) {
-                    LogMsg(QString("Couldn't load RSS Feed '%1'. URL is required.")
+                    LogMsg(tr("Couldn't load RSS Feed '%1'. URL is required.")
                            .arg(QString("%1\\%2").arg(folder->path(), key)), Log::WARNING);
                     continue;
                 }
@@ -307,13 +305,13 @@ void Session::loadFolder(const QJsonObject &jsonObj, Folder *folder)
                 if (valObj.contains("uid")) {
                     uid = QUuid {valObj["uid"].toString()};
                     if (uid.isNull()) {
-                        LogMsg(QString("Couldn't load RSS Feed '%1'. UID is invalid.")
+                        LogMsg(tr("Couldn't load RSS Feed '%1'. UID is invalid.")
                                .arg(QString("%1\\%2").arg(folder->path(), key)), Log::WARNING);
                         continue;
                     }
 
                     if (m_feedsByUID.contains(uid)) {
-                        LogMsg(QString("Duplicate RSS Feed UID: %1. Configuration seems to be corrupted.")
+                        LogMsg(tr("Duplicate RSS Feed UID: %1. Configuration seems to be corrupted.")
                                .arg(uid.toString()), Log::WARNING);
                         continue;
                     }
@@ -331,8 +329,8 @@ void Session::loadFolder(const QJsonObject &jsonObj, Folder *folder)
             }
         }
         else {
-            LogMsg(QString("Couldn't load RSS Item '%1'. Invalid data format.")
-                   .arg(QString("%1\\%2").arg(folder->path(), key)), Log::WARNING);
+            LogMsg(tr("Couldn't load RSS Item '%1'. Invalid data format.")
+                   .arg(QString::fromLatin1("%1\\%2").arg(folder->path(), key)), Log::WARNING);
         }
     }
 
@@ -482,7 +480,7 @@ uint Session::refreshInterval() const
     return m_refreshInterval;
 }
 
-void Session::setRefreshInterval(uint refreshInterval)
+void Session::setRefreshInterval(const uint refreshInterval)
 {
     if (m_refreshInterval != refreshInterval) {
         SettingsStorage::instance()->storeValue(SettingsKey_RefreshInterval, refreshInterval);
@@ -528,7 +526,7 @@ int Session::maxArticlesPerFeed() const
     return m_maxArticlesPerFeed;
 }
 
-void Session::setMaxArticlesPerFeed(int n)
+void Session::setMaxArticlesPerFeed(const int n)
 {
     if (m_maxArticlesPerFeed != n) {
         m_maxArticlesPerFeed = n;
