@@ -38,6 +38,11 @@
 using PluginVersion = Utils::Version<unsigned short, 2>;
 Q_DECLARE_METATYPE(PluginVersion)
 
+namespace Net
+{
+    struct DownloadResult;
+}
+
 struct PluginInfo
 {
     QString name;
@@ -102,12 +107,10 @@ private:
     void updateNova();
     void parseVersionInfo(const QByteArray &info);
     void installPlugin_impl(const QString &name, const QString &path);
-    bool isUpdateNeeded(QString pluginName, PluginVersion newVersion) const;
+    bool isUpdateNeeded(const QString &pluginName, PluginVersion newVersion) const;
 
-    void versionInfoDownloaded(const QString &url, const QByteArray &data);
-    void versionInfoDownloadFailed(const QString &url, const QString &reason);
-    void pluginDownloaded(const QString &url, QString filePath);
-    void pluginDownloadFailed(const QString &url, const QString &reason);
+    void versionInfoDownloadFinished(const Net::DownloadResult &result);
+    void pluginDownloadFinished(const Net::DownloadResult &result);
 
     static QString pluginPath(const QString &name);
 
