@@ -39,8 +39,20 @@ namespace Utils
 {
     namespace Fs
     {
+        /**
+         * Converts a path to a string suitable for display.
+         * This function makes sure the directory separator used is consistent
+         * with the OS being run.
+         */
         QString toNativePath(const QString &path);
-        QString fromNativePath(const QString &path);
+        /**
+         * Converts a path to a string suitable for processing.
+         * This function makes sure the directory separator used is independent
+         * from the OS being run so it is the same on all supported platforms.
+         * Slash ('/') is used as "uniform" directory separator.
+         */
+        QString toUniformPath(const QString &path);
+
         QString fileExtension(const QString &filename);
         QString fileName(const QString &filePath);
         QString folderName(const QString &filePath);
