@@ -31,12 +31,11 @@
 
 #include <cmath>
 
-#include <QByteArray>
 #include <QCollator>
 #include <QLocale>
 #include <QRegExp>
 #include <QtGlobal>
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
 #include <QThreadStorage>
 #endif
 
@@ -114,8 +113,8 @@ namespace
 
                     // both string/view has the same length
                     for (int i = 0; i < numViewL.length(); ++i) {
-                        const QChar numL = numViewL.at(i);
-                        const QChar numR = numViewR.at(i);
+                        const QChar numL = numViewL[i];
+                        const QChar numR = numViewR[i];
 
                         if (numL != numR)
                             return (numL.unicode() - numR.unicode());
@@ -140,7 +139,7 @@ int Utils::String::naturalCompare(const QString &left, const QString &right, con
     // provide a single `NaturalCompare` instance for easy use
     // https://doc.qt.io/qt-5/threads-reentrancy.html
     if (caseSensitivity == Qt::CaseSensitive) {
-#ifdef Q_OS_MAC  // workaround for Apple xcode: https://stackoverflow.com/a/29929949
+#ifdef Q_OS_MACOS  // workaround for Apple xcode: https://stackoverflow.com/a/29929949
         static QThreadStorage<NaturalCompare> nCmp;
         if (!nCmp.hasLocalData())
             nCmp.setLocalData(NaturalCompare(Qt::CaseSensitive));
@@ -151,7 +150,7 @@ int Utils::String::naturalCompare(const QString &left, const QString &right, con
 #endif
     }
 
-#ifdef Q_OS_MAC
+#ifdef Q_OS_MACOS
     static QThreadStorage<NaturalCompare> nCmp;
     if (!nCmp.hasLocalData())
         nCmp.setLocalData(NaturalCompare(Qt::CaseInsensitive));
@@ -163,7 +162,7 @@ int Utils::String::naturalCompare(const QString &left, const QString &right, con
 }
 
 // to send numbers instead of strings with suffixes
-QString Utils::String::fromDouble(double n, int precision)
+QString Utils::String::fromDouble(const double n, const int precision)
 {
     /* HACK because QString rounds up. Eg QString::number(0.999*100.0, 'f' ,1) == 99.9
     ** but QString::number(0.9999*100.0, 'f' ,1) == 100.0 The problem manifests when
@@ -171,24 +170,10 @@ QString Utils::String::fromDouble(double n, int precision)
     ** our 'wanted' is >= 5. In this case our last digit gets rounded up. So for each
     ** precision we add an extra 0 behind 1 in the below algorithm. */
 
-    double prec = std::pow(10.0, precision);
+    const double prec = std::pow(10.0, precision);
     return QLocale::system().toString(std::floor(n * prec) / prec, 'f', precision);
 }
 
-// Implements constant-time comparison to protect against timing attacks
-// Taken from https://crackstation.net/hashing-security.htm
-bool Utils::String::slowEquals(const QByteArray &a, const QByteArray &b)
-{
-    int lengthA = a.length();
-    int lengthB = b.length();
-
-    int diff = lengthA ^ lengthB;
-    for (int i = 0; (i < lengthA) && (i < lengthB); ++i)
-        diff |= a[i] ^ b[i];
-
-    return (diff == 0);
-}
-
 // This is marked as internal in QRegExp.cpp, but is exported. The alternative would be to
 // copy the code from QRegExp::wc2rx().
 QString qt_regexp_toCanonical(const QString &pattern, QRegExp::PatternSyntax patternSyntax);
