@@ -30,11 +30,12 @@
 #ifndef UTILS_STRING_H
 #define UTILS_STRING_H
 
-#include <QString>
+#include <QLatin1String>
 #include <QVector>
 
-class QByteArray;
-class QLatin1String;
+class QString;
+class QStringRef;
+
 class TriStateBool;
 
 namespace Utils
@@ -43,10 +44,6 @@ namespace Utils
     {
         QString fromDouble(double n, int precision);
 
-        // Implements constant-time comparison to protect against timing attacks
-        // Taken from https://crackstation.net/hashing-security.htm
-        bool slowEquals(const QByteArray &a, const QByteArray &b);
-
         int naturalCompare(const QString &left, const QString &right, const Qt::CaseSensitivity caseSensitivity);
         template <Qt::CaseSensitivity caseSensitivity>
         bool naturalLessThan(const QString &left, const QString &right)
@@ -69,7 +66,7 @@ namespace Utils
             return str;
         }
 
-        bool parseBool(const QString &string, const bool defaultValue);
+        bool parseBool(const QString &string, bool defaultValue);
         TriStateBool parseTriStateBool(const QString &string);
 
         QString join(const QVector<QStringRef> &strings, const QString &separator);
