@@ -29,8 +29,9 @@
 #ifndef ADDNEWTORRENTDIALOG_H
 #define ADDNEWTORRENTDIALOG_H
 
+#include <memory>
+
 #include <QDialog>
-#include <QScopedPointer>
 
 #include "base/bittorrent/addtorrentparams.h"
 #include "base/bittorrent/infohash.h"
@@ -42,6 +43,11 @@ namespace BitTorrent
     class MagnetUri;
 }
 
+namespace Net
+{
+    struct DownloadResult;
+}
+
 namespace Ui
 {
     class AddNewTorrentDialog;
@@ -51,15 +57,16 @@ class PropListDelegate;
 class TorrentContentFilterModel;
 class TorrentFileGuard;
 
-class AddNewTorrentDialog : public QDialog
+class AddNewTorrentDialog final : public QDialog
 {
     Q_OBJECT
+    Q_DISABLE_COPY(AddNewTorrentDialog)
 
 public:
     static const int minPathHistoryLength = 0;
     static const int maxPathHistoryLength = 99;
 
-    ~AddNewTorrentDialog();
+    ~AddNewTorrentDialog() override;
 
     static bool isEnabled();
     static void setEnabled(bool value);
@@ -68,17 +75,15 @@ public:
     static int savePathHistoryLength();
     static void setSavePathHistoryLength(int value);
 
-    static void show(QString source, const BitTorrent::AddTorrentParams &inParams, QWidget *parent);
-    static void show(QString source, QWidget *parent);
+    static void show(const QString &source, const BitTorrent::AddTorrentParams &inParams, QWidget *parent);
+    static void show(const QString &source, QWidget *parent);
 
 private slots:
     void displayContentTreeMenu(const QPoint &);
     void updateDiskSpaceLabel();
     void onSavePathChanged(const QString &newPath);
     void updateMetadata(const BitTorrent::TorrentInfo &info);
-    void handleDownloadFailed(const QString &url, const QString &reason);
-    void handleRedirectedToMagnet(const QString &url, const QString &magnetUri);
-    void handleDownloadFinished(const QString &url, const QString &filePath);
+    void handleDownloadFinished(const Net::DownloadResult &result);
     void TMMChanged(int index);
     void categoryChanged(int index);
     void doNotDeleteTorrentClicked(bool checked);
@@ -88,16 +93,18 @@ private slots:
 
 private:
     explicit AddNewTorrentDialog(const BitTorrent::AddTorrentParams &inParams, QWidget *parent);
-    bool loadTorrent(const QString &torrentPath);
+    bool loadTorrentFile(const QString &torrentPath);
+    bool loadTorrentImpl();
     bool loadMagnet(const BitTorrent::MagnetUri &magnetUri);
     void populateSavePathComboBox();
     void saveSavePathHistory() const;
     int indexOfSavePath(const QString &savePath);
     void loadState();
     void saveState();
-    void setMetadataProgressIndicator(bool visibleIndicator, const QString &labelText = QString());
+    void setMetadataProgressIndicator(bool visibleIndicator, const QString &labelText = {});
     void setupTreeview();
     void setSavePath(const QString &newPath);
+    void saveTorrentFile();
 
     void showEvent(QShowEvent *event) override;
 
@@ -105,12 +112,11 @@ private:
     TorrentContentFilterModel *m_contentModel;
     PropListDelegate *m_contentDelegate;
     bool m_hasMetadata;
-    QString m_filePath;
     BitTorrent::InfoHash m_hash;
     BitTorrent::TorrentInfo m_torrentInfo;
     QByteArray m_headerState;
     int m_oldIndex;
-    QScopedPointer<TorrentFileGuard> m_torrentGuard;
+    std::unique_ptr<TorrentFileGuard> m_torrentGuard;
     BitTorrent::AddTorrentParams m_torrentParams;
 
     CachedSettingValue<QSize> m_storeDialogSize;
