@@ -33,7 +33,7 @@
 #include <QList>
 #include <QNetworkCookie>
 
-class CookiesModel : public QAbstractItemModel
+class CookiesModel final : public QAbstractItemModel
 {
      Q_OBJECT
 
@@ -54,18 +54,18 @@ public:
     QList<QNetworkCookie> cookies() const;
 
     QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex index(int row, int column, const QModelIndex &parent = {}) const override;
     QModelIndex parent(const QModelIndex &index) const override;
 
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    int rowCount(const QModelIndex &parent = {}) const override;
+    int columnCount(const QModelIndex &parent = {}) const override;
 
     Qt::ItemFlags flags(const QModelIndex &index) const override;
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
     bool setData(const QModelIndex &index, const QVariant &value, int role) override;
-    bool insertRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
-    bool removeRows(int row, int count, const QModelIndex &parent = QModelIndex()) override;
+    bool insertRows(int row, int count, const QModelIndex &parent = {}) override;
+    bool removeRows(int row, int count, const QModelIndex &parent = {}) override;
 
 private:
     mutable QList<QNetworkCookie> m_cookies;
