@@ -29,10 +29,14 @@
 #ifndef MACUTILITIES_H
 #define MACUTILITIES_H
 
-#include <QPixmap>
-#include <QSize>
 #include <objc/objc.h>
 
+#include <QSet>
+
+class QPixmap;
+class QSize;
+class QString;
+
 namespace MacUtils
 {
     QPixmap pixmapForExtension(const QString &ext, const QSize &size);
