@@ -33,10 +33,13 @@
 #include <QDebug>
 #include <QHelpEvent>
 #include <QPainter>
+#include <QPainterPath>
 #include <QTextStream>
 #include <QToolTip>
 
+#include "base/indexrange.h"
 #include "base/bittorrent/torrenthandle.h"
+#include "base/bittorrent/torrentinfo.h"
 #include "base/utils/misc.h"
 
 namespace
@@ -118,7 +121,7 @@ PiecesBar::PiecesBar(QWidget *parent)
     setMouseTracking(true);
 }
 
-void PiecesBar::setTorrent(BitTorrent::TorrentHandle *torrent)
+void PiecesBar::setTorrent(const BitTorrent::TorrentHandle *torrent)
 {
     m_torrent = torrent;
     if (!m_torrent)
@@ -147,9 +150,8 @@ bool PiecesBar::event(QEvent *e)
         showToolTip(static_cast<QHelpEvent *>(e));
         return true;
     }
-    else {
-        return base::event(e);
-    }
+
+    return base::event(e);
 }
 
 void PiecesBar::enterEvent(QEvent *e)
