@@ -29,28 +29,25 @@
 #ifndef PROPERTIESWIDGET_H
 #define PROPERTIESWIDGET_H
 
-#include <QShortcut>
+#include <QList>
 #include <QWidget>
 
-#include "base/bittorrent/torrenthandle.h"
-
-class QAction;
 class QPushButton;
-class QTimer;
 class QTreeView;
 
 class DownloadedPiecesBar;
 class LineEdit;
-class MainWindow;
 class PeerListWidget;
 class PieceAvailabilityBar;
 class PropListDelegate;
 class PropTabBar;
-class SpeedWidget;
-class torrent_file;
 class TorrentContentFilterModel;
 class TrackerListWidget;
-class TransferListWidget;
+
+namespace BitTorrent
+{
+    class TorrentHandle;
+}
 
 namespace Ui
 {
@@ -69,8 +66,9 @@ public:
         VISIBLE
     };
 
-    PropertiesWidget(QWidget *parent, MainWindow *mainWindow, TransferListWidget *transferList);
-    ~PropertiesWidget();
+    explicit PropertiesWidget(QWidget *parent);
+    ~PropertiesWidget() override;
+
     BitTorrent::TorrentHandle *getCurrentTorrent() const;
     TrackerListWidget *getTrackerList() const;
     PeerListWidget *getPeerList() const;
@@ -78,6 +76,7 @@ public:
 
 public slots:
     void setVisibility(bool visible);
+    void loadTorrentInfos(BitTorrent::TorrentHandle *const torrent);
     void loadDynamicData();
     void clear();
     void readSettings();
@@ -86,20 +85,15 @@ public slots:
     void openDoubleClickedFile(const QModelIndex &);
     void loadTrackers(BitTorrent::TorrentHandle *const torrent);
 
-protected:
-    QPushButton *getButtonFromIndex(int index);
-    void applyPriorities();
-
 protected slots:
-    void loadTorrentInfos(BitTorrent::TorrentHandle *const torrent);
     void updateTorrentInfos(BitTorrent::TorrentHandle *const torrent);
     void loadUrlSeeds();
     void askWebSeed();
     void deleteSelectedUrlSeeds();
     void copySelectedWebSeedsToClipboard() const;
     void editWebSeed();
-    void displayFilesListMenu(const QPoint &pos);
-    void displayWebSeedListMenu(const QPoint &pos);
+    void displayFilesListMenu(const QPoint &);
+    void displayWebSeedListMenu(const QPoint &);
     void filteredFilesChanged();
     void showPiecesDownloaded(bool show);
     void showPiecesAvailability(bool show);
@@ -111,14 +105,13 @@ private slots:
     void updateSavePath(BitTorrent::TorrentHandle *const torrent);
 
 private:
+    QPushButton *getButtonFromIndex(int index);
+    void applyPriorities();
     void openFile(const QModelIndex &index);
     void openFolder(const QModelIndex &index, bool containingFolder);
 
     Ui::PropertiesWidget *m_ui;
-    TransferListWidget *m_transferList;
-    MainWindow *m_mainWindow;
     BitTorrent::TorrentHandle *m_torrent;
-    QTimer *m_refreshTimer;
     SlideState m_state;
     TorrentContentFilterModel *m_propListModel;
     PropListDelegate *m_propListDelegate;
@@ -130,10 +123,6 @@ private:
     PieceAvailabilityBar *m_piecesAvailability;
     PropTabBar *m_tabBar;
     LineEdit *m_contentFilterLine;
-    QShortcut *m_editHotkeyFile;
-    QShortcut *m_editHotkeyWeb;
-    QShortcut *m_deleteHotkeyWeb;
-    QShortcut *m_openHotkeyFile;
 };
 
 #endif // PROPERTIESWIDGET_H
