@@ -32,16 +32,15 @@
 #include <QComboBox>
 #include <QWidget>
 
-#include "speedplotview.h"
-
-class QVBoxLayout;
 class QHBoxLayout;
 class QLabel;
 class QMenu;
-class QSignalMapper;
-class PropertiesWidget;
+class QVBoxLayout;
 
-class ComboBoxMenuButton : public QComboBox
+class PropertiesWidget;
+class SpeedPlotView;
+
+class ComboBoxMenuButton final : public QComboBox
 {
     Q_OBJECT
 
@@ -59,7 +58,7 @@ class SpeedWidget : public QWidget
     Q_OBJECT
 
 public:
-    SpeedWidget(PropertiesWidget *parent);
+    explicit SpeedWidget(PropertiesWidget *parent);
     ~SpeedWidget();
 
 private slots:
@@ -80,7 +79,6 @@ private:
     ComboBoxMenuButton *m_graphsButton;
     QMenu *m_graphsMenu;
     QList<QAction *> m_graphsMenuActions;
-    QSignalMapper *m_graphsSignalMapper;
 };
 
 #endif // SPEEDWIDGET_H
