@@ -35,12 +35,9 @@
 #include "base/bittorrent/torrenthandle.h"
 #include "base/bittorrent/trackerentry.h"
 #include "base/global.h"
-#include "base/net/downloadhandler.h"
 #include "base/net/downloadmanager.h"
-#include "base/utils/fs.h"
-#include "base/utils/misc.h"
-#include "guiiconprovider.h"
 #include "ui_trackersadditiondialog.h"
+#include "uithememanager.h"
 
 TrackersAdditionDialog::TrackersAdditionDialog(QWidget *parent, BitTorrent::TorrentHandle *const torrent)
     : QDialog(parent)
@@ -49,7 +46,7 @@ TrackersAdditionDialog::TrackersAdditionDialog(QWidget *parent, BitTorrent::Torr
 {
     m_ui->setupUi(this);
     // Icons
-    m_ui->uTorrentListButton->setIcon(GuiIconProvider::instance()->getIcon("download"));
+    m_ui->uTorrentListButton->setIcon(UIThemeManager::instance()->getIcon("download"));
 }
 
 TrackersAdditionDialog::~TrackersAdditionDialog()
@@ -59,11 +56,13 @@ TrackersAdditionDialog::~TrackersAdditionDialog()
 
 QStringList TrackersAdditionDialog::newTrackers() const
 {
+    const QString plainText = m_ui->textEditTrackersList->toPlainText();
+
     QStringList cleanTrackers;
-    for (QString url : asConst(m_ui->textEditTrackersList->toPlainText().split('\n'))) {
+    for (QStringRef url : asConst(plainText.splitRef('\n'))) {
         url = url.trimmed();
         if (!url.isEmpty())
-            cleanTrackers << url;
+            cleanTrackers << url.toString();
     }
     return cleanTrackers;
 }
@@ -71,22 +70,30 @@ QStringList TrackersAdditionDialog::newTrackers() const
 void TrackersAdditionDialog::on_uTorrentListButton_clicked()
 {
     m_ui->uTorrentListButton->setEnabled(false);
-    Net::DownloadHandler *handler = Net::DownloadManager::instance()->download({m_ui->lineEditListURL->text()});
-    connect(handler, static_cast<void (Net::DownloadHandler::*)(const QString &, const QByteArray &)>(&Net::DownloadHandler::downloadFinished)
-            , this, &TrackersAdditionDialog::parseUTorrentList);
-    connect(handler, &Net::DownloadHandler::downloadFailed, this, &TrackersAdditionDialog::getTrackerError);
+    Net::DownloadManager::instance()->download(m_ui->lineEditListURL->text()
+                                               , this, &TrackersAdditionDialog::torrentListDownloadFinished);
     // Just to show that it takes times
     setCursor(Qt::WaitCursor);
 }
 
-void TrackersAdditionDialog::parseUTorrentList(const QString &, const QByteArray &data)
+void TrackersAdditionDialog::torrentListDownloadFinished(const Net::DownloadResult &result)
 {
-    // Load from torrent handle
-    QList<BitTorrent::TrackerEntry> existingTrackers = m_torrent->trackers();
-    // Load from current user list
-    const QStringList tmp = m_ui->textEditTrackersList->toPlainText().split('\n');
-    for (const QString &userURL : tmp) {
-        BitTorrent::TrackerEntry userTracker(userURL);
+    if (result.status != Net::DownloadStatus::Success) {
+        // To restore the cursor ...
+        setCursor(Qt::ArrowCursor);
+        m_ui->uTorrentListButton->setEnabled(true);
+        QMessageBox::warning(
+                    this, tr("Download error")
+                    , tr("The trackers list could not be downloaded, reason: %1")
+                    .arg(result.errorString), QMessageBox::Ok);
+        return;
+    }
+
+    const QStringList trackersFromUser = m_ui->textEditTrackersList->toPlainText().split('\n');
+    QVector<BitTorrent::TrackerEntry> existingTrackers = m_torrent->trackers();
+    existingTrackers.reserve(trackersFromUser.size());
+    for (const QString &userURL : trackersFromUser) {
+        const BitTorrent::TrackerEntry userTracker(userURL);
         if (!existingTrackers.contains(userTracker))
             existingTrackers << userTracker;
     }
@@ -96,7 +103,7 @@ void TrackersAdditionDialog::parseUTorrentList(const QString &, const QByteArray
         m_ui->textEditTrackersList->insertPlainText("\n");
     int nb = 0;
     QBuffer buffer;
-    buffer.setData(data);
+    buffer.setData(result.data);
     buffer.open(QBuffer::ReadOnly);
     while (!buffer.atEnd()) {
         const QString line = buffer.readLine().trimmed();
@@ -117,14 +124,6 @@ void TrackersAdditionDialog::parseUTorrentList(const QString &, const QByteArray
         QMessageBox::information(this, tr("No change"), tr("No additional trackers were found."), QMessageBox::Ok);
 }
 
-void TrackersAdditionDialog::getTrackerError(const QString &, const QString &error)
-{
-    // To restore the cursor ...
-    setCursor(Qt::ArrowCursor);
-    m_ui->uTorrentListButton->setEnabled(true);
-    QMessageBox::warning(this, tr("Download error"), tr("The trackers list could not be downloaded, reason: %1").arg(error), QMessageBox::Ok);
-}
-
 QStringList TrackersAdditionDialog::askForTrackers(QWidget *parent, BitTorrent::TorrentHandle *const torrent)
 {
     QStringList trackers;
