@@ -40,15 +40,13 @@
 #include <QTableView>
 
 #include "base/global.h"
-#include "base/net/downloadhandler.h"
 #include "base/net/downloadmanager.h"
 #include "base/utils/fs.h"
-#include "base/utils/misc.h"
 #include "autoexpandabledialog.h"
-#include "guiiconprovider.h"
 #include "pluginsourcedialog.h"
 #include "searchwidget.h"
 #include "ui_pluginselectdialog.h"
+#include "uithememanager.h"
 #include "utils.h"
 
 enum PluginColumns
@@ -81,7 +79,7 @@ PluginSelectDialog::PluginSelectDialog(SearchPluginManager *pluginManager, QWidg
     m_ui->pluginsTree->hideColumn(PLUGIN_ID);
     m_ui->pluginsTree->header()->setSortIndicator(0, Qt::AscendingOrder);
 
-    m_ui->actionUninstall->setIcon(GuiIconProvider::instance()->getIcon("list-remove"));
+    m_ui->actionUninstall->setIcon(UIThemeManager::instance()->getIcon("list-remove"));
 
     connect(m_ui->actionEnable, &QAction::toggled, this, &PluginSelectDialog::enableSelection);
     connect(m_ui->pluginsTree, &QTreeWidget::customContextMenuRequested, this, &PluginSelectDialog::displayContextMenu);
@@ -121,7 +119,7 @@ void PluginSelectDialog::dropEvent(QDropEvent *event)
         }
     }
     else {
-        files = event->mimeData()->text().split(QLatin1String("\n"));
+        files = event->mimeData()->text().split('\n');
     }
 
     if (files.isEmpty()) return;
@@ -165,19 +163,22 @@ void PluginSelectDialog::togglePluginState(QTreeWidgetItem *item, int)
     }
 }
 
-void PluginSelectDialog::displayContextMenu(const QPoint&)
+void PluginSelectDialog::displayContextMenu(const QPoint &)
 {
-    QMenu myContextMenu(this);
     // Enable/disable pause/start action given the DL state
-    QList<QTreeWidgetItem *> items = m_ui->pluginsTree->selectedItems();
+    const QList<QTreeWidgetItem *> items = m_ui->pluginsTree->selectedItems();
     if (items.isEmpty()) return;
 
-    QString firstID = items.first()->text(PLUGIN_ID);
+    QMenu *myContextMenu = new QMenu(this);
+    myContextMenu->setAttribute(Qt::WA_DeleteOnClose);
+
+    const QString firstID = items.first()->text(PLUGIN_ID);
     m_ui->actionEnable->setChecked(m_pluginManager->pluginInfo(firstID)->enabled);
-    myContextMenu.addAction(m_ui->actionEnable);
-    myContextMenu.addSeparator();
-    myContextMenu.addAction(m_ui->actionUninstall);
-    myContextMenu.exec(QCursor::pos());
+    myContextMenu->addAction(m_ui->actionEnable);
+    myContextMenu->addSeparator();
+    myContextMenu->addAction(m_ui->actionUninstall);
+
+    myContextMenu->popup(QCursor::pos());
 }
 
 void PluginSelectDialog::on_closeButton_clicked()
@@ -229,17 +230,18 @@ void PluginSelectDialog::enableSelection(bool enable)
 }
 
 // Set the color of a row in data model
-void PluginSelectDialog::setRowColor(int row, QString color)
+void PluginSelectDialog::setRowColor(const int row, const QString &color)
 {
     QTreeWidgetItem *item = m_ui->pluginsTree->topLevelItem(row);
     for (int i = 0; i < m_ui->pluginsTree->columnCount(); ++i) {
-        item->setData(i, Qt::ForegroundRole, QVariant(QColor(color)));
+        item->setData(i, Qt::ForegroundRole, QColor(color));
     }
 }
 
-QList<QTreeWidgetItem*> PluginSelectDialog::findItemsWithUrl(QString url)
+QVector<QTreeWidgetItem*> PluginSelectDialog::findItemsWithUrl(const QString &url)
 {
-    QList<QTreeWidgetItem*> res;
+    QVector<QTreeWidgetItem*> res;
+    res.reserve(m_ui->pluginsTree->topLevelItemCount());
 
     for (int i = 0; i < m_ui->pluginsTree->topLevelItemCount(); ++i) {
         QTreeWidgetItem *item = m_ui->pluginsTree->topLevelItem(i);
@@ -250,7 +252,7 @@ QList<QTreeWidgetItem*> PluginSelectDialog::findItemsWithUrl(QString url)
     return res;
 }
 
-QTreeWidgetItem *PluginSelectDialog::findItemWithID(QString id)
+QTreeWidgetItem *PluginSelectDialog::findItemWithID(const QString &id)
 {
     for (int i = 0; i < m_ui->pluginsTree->topLevelItemCount(); ++i) {
         QTreeWidgetItem *item = m_ui->pluginsTree->topLevelItem(i);
@@ -269,9 +271,9 @@ void PluginSelectDialog::loadSupportedSearchPlugins()
         addNewPlugin(name);
 }
 
-void PluginSelectDialog::addNewPlugin(QString pluginName)
+void PluginSelectDialog::addNewPlugin(const QString &pluginName)
 {
-    QTreeWidgetItem *item = new QTreeWidgetItem(m_ui->pluginsTree);
+    auto *item = new QTreeWidgetItem(m_ui->pluginsTree);
     PluginInfo *plugin = m_pluginManager->pluginInfo(pluginName);
     item->setText(PLUGIN_NAME, plugin->fullName);
     item->setText(PLUGIN_URL, plugin->url);
@@ -287,16 +289,14 @@ void PluginSelectDialog::addNewPlugin(QString pluginName)
     // Handle icon
     if (QFile::exists(plugin->iconPath)) {
         // Good, we already have the icon
-        item->setData(PLUGIN_NAME, Qt::DecorationRole, QVariant(QIcon(plugin->iconPath)));
+        item->setData(PLUGIN_NAME, Qt::DecorationRole, QIcon(plugin->iconPath));
     }
     else {
         // Icon is missing, we must download it
         using namespace Net;
-        DownloadHandler *handler = DownloadManager::instance()->download(
-                    DownloadRequest(plugin->url + "/favicon.ico").saveToFile(true));
-        connect(handler, static_cast<void (DownloadHandler::*)(const QString &, const QString &)>(&DownloadHandler::downloadFinished)
-                , this, &PluginSelectDialog::iconDownloaded);
-        connect(handler, &DownloadHandler::downloadFailed, this, &PluginSelectDialog::iconDownloadFailed);
+        DownloadManager::instance()->download(
+                    DownloadRequest(plugin->url + "/favicon.ico").saveToFile(true)
+                    , this, &PluginSelectDialog::iconDownloadFinished);
     }
     item->setText(PLUGIN_VERSION, plugin->version);
 }
@@ -327,7 +327,7 @@ void PluginSelectDialog::finishPluginUpdate()
 
 void PluginSelectDialog::on_installButton_clicked()
 {
-    PluginSourceDialog *dlg = new PluginSourceDialog(this);
+    auto *dlg = new PluginSourceDialog(this);
     connect(dlg, &PluginSourceDialog::askForLocalFile, this, &PluginSelectDialog::askForLocalPlugin);
     connect(dlg, &PluginSourceDialog::askForUrl, this, &PluginSelectDialog::askForPluginUrl);
 }
@@ -337,7 +337,7 @@ void PluginSelectDialog::askForPluginUrl()
     bool ok = false;
     QString clipTxt = qApp->clipboard()->text();
     QString defaultUrl = "http://";
-    if (Utils::Misc::isUrl(clipTxt) && clipTxt.endsWith(".py"))
+    if (Net::DownloadManager::hasSupportedScheme(clipTxt) && clipTxt.endsWith(".py"))
       defaultUrl = clipTxt;
     QString url = AutoExpandableDialog::getText(
                 this, tr("New search engine plugin URL"),
@@ -370,9 +370,14 @@ void PluginSelectDialog::askForLocalPlugin()
     }
 }
 
-void PluginSelectDialog::iconDownloaded(const QString &url, QString filePath)
+void PluginSelectDialog::iconDownloadFinished(const Net::DownloadResult &result)
 {
-    filePath = Utils::Fs::fromNativePath(filePath);
+    if (result.status != Net::DownloadStatus::Success) {
+        qDebug("Could not download favicon: %s, reason: %s", qUtf8Printable(result.url), qUtf8Printable(result.errorString));
+        return;
+    }
+
+    const QString filePath = Utils::Fs::toUniformPath(result.filePath);
 
     // Icon downloaded
     QIcon icon(filePath);
@@ -380,7 +385,7 @@ void PluginSelectDialog::iconDownloaded(const QString &url, QString filePath)
     QList<QSize> sizes = icon.availableSizes();
     bool invalid = (sizes.isEmpty() || icon.pixmap(sizes.first()).isNull());
     if (!invalid) {
-        for (QTreeWidgetItem *item : asConst(findItemsWithUrl(url))) {
+        for (QTreeWidgetItem *item : asConst(findItemsWithUrl(result.url))) {
             QString id = item->text(PLUGIN_ID);
             PluginInfo *plugin = m_pluginManager->pluginInfo(id);
             if (!plugin) continue;
@@ -388,7 +393,7 @@ void PluginSelectDialog::iconDownloaded(const QString &url, QString filePath)
             QString iconPath = QString("%1/%2.%3")
                 .arg(SearchPluginManager::pluginsLocation()
                     , id
-                    , url.endsWith(".ico", Qt::CaseInsensitive) ? "ico" : "png");
+                    , result.url.endsWith(".ico", Qt::CaseInsensitive) ? "ico" : "png");
             if (QFile::copy(filePath, iconPath)) {
                 // This 2nd check is necessary. Some favicons (eg from piratebay)
                 // decode fine without an ext, but fail to do so when appending the ext
@@ -410,11 +415,6 @@ void PluginSelectDialog::iconDownloaded(const QString &url, QString filePath)
     Utils::Fs::forceRemove(filePath);
 }
 
-void PluginSelectDialog::iconDownloadFailed(const QString &url, const QString &reason)
-{
-    qDebug("Could not download favicon: %s, reason: %s", qUtf8Printable(url), qUtf8Printable(reason));
-}
-
 void PluginSelectDialog::checkForUpdatesFinished(const QHash<QString, PluginVersion> &updateInfo)
 {
     finishAsyncOp();
