@@ -36,23 +36,22 @@
 
 class QHeaderView;
 class QModelIndex;
-class QStandardItem;
 class QStandardItemModel;
 
-template <typename T> class CachedSettingValue;
-
 class LineEdit;
 class SearchHandler;
 class SearchListDelegate;
 class SearchSortModel;
 struct SearchResult;
 
+template <typename T> class CachedSettingValue;
+
 namespace Ui
 {
     class SearchJobWidget;
 }
 
-class SearchJobWidget : public QWidget
+class SearchJobWidget final : public QWidget
 {
     Q_OBJECT
     Q_DISABLE_COPY(SearchJobWidget)
@@ -83,10 +82,6 @@ public:
 
     void cancelSearch();
 
-    void downloadTorrents();
-    void openTorrentPages();
-    void copyTorrentURLs();
-
 signals:
     void resultsCountUpdated();
     void statusChanged();
@@ -100,11 +95,12 @@ private:
     void updateFilter();
     void filterSearchResults(const QString &name);
     void showFilterContextMenu(const QPoint &);
-    void displayToggleColumnsMenu(const QPoint&);
+    void contextMenuEvent(QContextMenuEvent *event) override;
+    void displayToggleColumnsMenu(const QPoint &);
     void onItemDoubleClicked(const QModelIndex &index);
     void searchFinished(bool cancelled);
     void searchFailed();
-    void appendSearchResults(const QList<SearchResult> &results);
+    void appendSearchResults(const QVector<SearchResult> &results);
     void updateResultsCount();
     void setStatus(Status value);
     void downloadTorrent(const QModelIndex &rowIndex);
@@ -114,6 +110,13 @@ private:
     QHeaderView *header() const;
     void setRowColor(int row, const QColor &color);
 
+    void downloadTorrents();
+    void openTorrentPages() const;
+    void copyTorrentURLs() const;
+    void copyTorrentDownloadLinks() const;
+    void copyTorrentNames() const;
+    void copyField(int column) const;
+
     static QString statusText(Status st);
     static CachedSettingValue<NameFilteringMode> &nameFilteringModeSetting();
 
