@@ -28,6 +28,8 @@
 
 #include "statsdialog.h"
 
+#include <algorithm>
+
 #include "base/bittorrent/cachestatus.h"
 #include "base/bittorrent/session.h"
 #include "base/bittorrent/sessionstatus.h"
@@ -78,29 +80,22 @@ void StatsDialog::update()
                 : "-");
     // Cache hits
     qreal readRatio = cs.readRatio;
-    m_ui->labelCacheHits->setText(QString("%1%").arg(
-        readRatio > 0
+    m_ui->labelCacheHits->setText(QString::fromLatin1("%1%").arg((readRatio > 0)
         ? Utils::String::fromDouble(100 * readRatio, 2)
-        : "0"));
+        : QLatin1String("0")));
     // Buffers size
     m_ui->labelTotalBuf->setText(Utils::Misc::friendlyUnit(cs.totalUsedBuffers * 16 * 1024));
     // Disk overload (100%) equivalent
     // From lt manual: disk_write_queue and disk_read_queue are the number of peers currently waiting on a disk write or disk read
     // to complete before it receives or sends any more data on the socket. It's a metric of how disk bound you are.
 
-    // num_peers is not reliable (adds up peers, which didn't even overcome tcp handshake)
-    quint32 peers = 0;
-    for (BitTorrent::TorrentHandle *const torrent : asConst(BitTorrent::Session::instance()->torrents()))
-        peers += torrent->peersCount();
+    m_ui->labelWriteStarve->setText(QString::fromLatin1("%1%").arg(((ss.diskWriteQueue > 0) && (ss.peersCount > 0))
+        ? Utils::String::fromDouble((100. * ss.diskWriteQueue / ss.peersCount), 2)
+        : QLatin1String("0")));
+    m_ui->labelReadStarve->setText(QString::fromLatin1("%1%").arg(((ss.diskReadQueue > 0) && (ss.peersCount > 0))
+        ? Utils::String::fromDouble((100. * ss.diskReadQueue / ss.peersCount), 2)
+        : QLatin1String("0")));
 
-    m_ui->labelWriteStarve->setText(QString("%1%")
-                                    .arg(((ss.diskWriteQueue > 0) && (peers > 0))
-                                         ? Utils::String::fromDouble((100. * ss.diskWriteQueue) / peers, 2)
-                                         : "0"));
-    m_ui->labelReadStarve->setText(QString("%1%")
-                                   .arg(((ss.diskReadQueue > 0) && (peers > 0))
-                                        ? Utils::String::fromDouble((100. * ss.diskReadQueue) / peers, 2)
-                                        : "0"));
     // Disk queues
     m_ui->labelQueuedJobs->setText(QString::number(cs.jobQueueLength));
     m_ui->labelJobsTime->setText(tr("%1 ms", "18 milliseconds").arg(cs.averageJobTime));
