@@ -39,14 +39,13 @@
 #include "base/bittorrent/session.h"
 #include "base/bittorrent/sessionstatus.h"
 #include "base/utils/misc.h"
-#include "guiiconprovider.h"
 #include "speedlimitdialog.h"
 #include "utils.h"
 
 StatusBar::StatusBar(QWidget *parent)
     : QStatusBar(parent)
 {
-#ifndef Q_OS_MAC
+#ifndef Q_OS_MACOS
     // Redefining global stylesheet breaks certain elements on mac like tabs.
     // Qt checks whether the stylesheet class inherts("QMacStyle") and this becomes false.
     qApp->setStyleSheet("QStatusBar::item { border-width: 0; }");
@@ -55,7 +54,7 @@ StatusBar::StatusBar(QWidget *parent)
     BitTorrent::Session *const session = BitTorrent::Session::instance();
     connect(session, &BitTorrent::Session::speedLimitModeChanged, this, &StatusBar::updateAltSpeedsBtn);
     QWidget *container = new QWidget(this);
-    QHBoxLayout *layout = new QHBoxLayout(container);
+    auto *layout = new QHBoxLayout(container);
     layout->setContentsMargins(0,0,0,0);
 
     container->setLayout(layout);
@@ -65,7 +64,7 @@ StatusBar::StatusBar(QWidget *parent)
     m_connecStatusLblIcon->setCursor(Qt::PointingHandCursor);
     m_connecStatusLblIcon->setIcon(QIcon(":/icons/skin/firewalled.svg"));
     m_connecStatusLblIcon->setToolTip(
-        QString(QLatin1String("<b>%1</b><br><i>%2</i>")).arg(tr("Connection status:")
+        QString::fromLatin1("<b>%1</b><br><i>%2</i>").arg(tr("Connection status:")
             , tr("No direct connections. This may indicate network configuration problems.")));
     connect(m_connecStatusLblIcon, &QAbstractButton::clicked, this, &StatusBar::connectionButtonClicked);
 
@@ -112,22 +111,22 @@ StatusBar::StatusBar(QWidget *parent)
 
     QFrame *statusSep1 = new QFrame(this);
     statusSep1->setFrameStyle(QFrame::VLine);
-#ifndef Q_OS_MAC
+#ifndef Q_OS_MACOS
     statusSep1->setFrameShadow(QFrame::Raised);
 #endif
     QFrame *statusSep2 = new QFrame(this);
     statusSep2->setFrameStyle(QFrame::VLine);
-#ifndef Q_OS_MAC
+#ifndef Q_OS_MACOS
     statusSep2->setFrameShadow(QFrame::Raised);
 #endif
     QFrame *statusSep3 = new QFrame(this);
     statusSep3->setFrameStyle(QFrame::VLine);
-#ifndef Q_OS_MAC
+#ifndef Q_OS_MACOS
     statusSep3->setFrameShadow(QFrame::Raised);
 #endif
     QFrame *statusSep4 = new QFrame(this);
     statusSep4->setFrameStyle(QFrame::VLine);
-#ifndef Q_OS_MAC
+#ifndef Q_OS_MACOS
     statusSep4->setFrameShadow(QFrame::Raised);
 #endif
     layout->addWidget(m_DHTLbl);
@@ -231,12 +230,12 @@ void StatusBar::refresh()
 void StatusBar::updateAltSpeedsBtn(bool alternative)
 {
     if (alternative) {
-        m_altSpeedsBtn->setIcon(QIcon(":/icons/slow.png"));
+        m_altSpeedsBtn->setIcon(QIcon(":/icons/slow.svg"));
         m_altSpeedsBtn->setToolTip(tr("Click to switch to regular speed limits"));
         m_altSpeedsBtn->setDown(true);
     }
     else {
-        m_altSpeedsBtn->setIcon(QIcon(":/icons/slow_off.png"));
+        m_altSpeedsBtn->setIcon(QIcon(":/icons/slow_off.svg"));
         m_altSpeedsBtn->setToolTip(tr("Click to switch to alternative speed limits"));
         m_altSpeedsBtn->setDown(false);
     }
