@@ -30,39 +30,45 @@
 #define TORRENTCONTENTMODEL_H
 
 #include <QAbstractItemModel>
-#include <QModelIndex>
-#include <QVariant>
 #include <QVector>
 
-#include "base/bittorrent/torrentinfo.h"
 #include "torrentcontentmodelitem.h"
 
 class QFileIconProvider;
+class QModelIndex;
+class QVariant;
+
 class TorrentContentModelFile;
 
-class TorrentContentModel : public QAbstractItemModel
+namespace BitTorrent
+{
+    class TorrentInfo;
+}
+
+class TorrentContentModel final : public QAbstractItemModel
 {
     Q_OBJECT
+    Q_DISABLE_COPY(TorrentContentModel)
 
 public:
     TorrentContentModel(QObject *parent = nullptr);
     ~TorrentContentModel() override;
 
     void updateFilesProgress(const QVector<qreal> &fp);
-    void updateFilesPriorities(const QVector<int> &fprio);
+    void updateFilesPriorities(const QVector<BitTorrent::DownloadPriority> &fprio);
     void updateFilesAvailability(const QVector<qreal> &fa);
-    QVector<int> getFilePriorities() const;
+    QVector<BitTorrent::DownloadPriority> getFilePriorities() const;
     bool allFiltered() const;
-    int columnCount(const QModelIndex &parent = QModelIndex()) const override;
+    int columnCount(const QModelIndex &parent = {}) const override;
     bool setData(const QModelIndex &index, const QVariant &value, int role = Qt::EditRole) override;
     TorrentContentModelItem::ItemType itemType(const QModelIndex &index) const;
     int getFileIndex(const QModelIndex &index);
     QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
     Qt::ItemFlags flags(const QModelIndex &index) const override;
     QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
-    QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override;
+    QModelIndex index(int row, int column, const QModelIndex &parent = {}) const override;
     QModelIndex parent(const QModelIndex &index) const override;
-    int rowCount(const QModelIndex &parent = QModelIndex()) const override;
+    int rowCount(const QModelIndex &parent = {}) const override;
     void clear();
     void setupModelData(const BitTorrent::TorrentInfo &info);
 
