@@ -29,17 +29,21 @@
 #ifndef TORRENTCONTENTMODELFILE_H
 #define TORRENTCONTENTMODELFILE_H
 
-#include "base/bittorrent/filepriority.h"
 #include "torrentcontentmodelitem.h"
 
-class TorrentContentModelFile : public TorrentContentModelItem
+namespace BitTorrent
+{
+    enum class DownloadPriority;
+}
+
+class TorrentContentModelFile final : public TorrentContentModelItem
 {
 public:
     TorrentContentModelFile(const QString &fileName, qulonglong fileSize,
                             TorrentContentModelFolder *parent, int fileIndex);
 
     int fileIndex() const;
-    void setPriority(BitTorrent::FilePriority newPriority, bool updateParent = true) override;
+    void setPriority(BitTorrent::DownloadPriority newPriority, bool updateParent = true) override;
     void setProgress(qreal progress);
     void setAvailability(qreal availability);
     ItemType itemType() const override;
