@@ -28,6 +28,8 @@
 
 #include "torrentcontentmodelfolder.h"
 
+#include <QVariant>
+
 #include "base/bittorrent/torrenthandle.h"
 #include "base/global.h"
 
@@ -41,7 +43,7 @@ TorrentContentModelFolder::TorrentContentModelFolder(const QString &name, Torren
         m_name.chop(4);
 }
 
-TorrentContentModelFolder::TorrentContentModelFolder(const QList<QVariant> &data)
+TorrentContentModelFolder::TorrentContentModelFolder(const QVector<QVariant> &data)
     : TorrentContentModelItem(nullptr)
 {
     Q_ASSERT(data.size() == NB_COL);
@@ -65,7 +67,7 @@ void TorrentContentModelFolder::deleteAllChildren()
     m_childItems.clear();
 }
 
-const QList<TorrentContentModelItem *> &TorrentContentModelFolder::children() const
+const QVector<TorrentContentModelItem *> &TorrentContentModelFolder::children() const
 {
     return m_childItems;
 }
@@ -86,9 +88,10 @@ TorrentContentModelItem *TorrentContentModelFolder::child(int row) const
 
 TorrentContentModelFolder *TorrentContentModelFolder::childFolderWithName(const QString &name) const
 {
-    for (TorrentContentModelItem *child : asConst(m_childItems))
+    for (TorrentContentModelItem *child : asConst(m_childItems)) {
         if ((child->itemType() == FolderType) && (child->name() == name))
             return static_cast<TorrentContentModelFolder *>(child);
+    }
     return nullptr;
 }
 
@@ -108,10 +111,10 @@ void TorrentContentModelFolder::updatePriority()
     // If all children have the same priority
     // then the folder should have the same
     // priority
-    const BitTorrent::FilePriority prio = m_childItems.first()->priority();
+    const BitTorrent::DownloadPriority prio = m_childItems.first()->priority();
     for (int i = 1; i < m_childItems.size(); ++i) {
         if (m_childItems.at(i)->priority() != prio) {
-            setPriority(BitTorrent::FilePriority::Mixed);
+            setPriority(BitTorrent::DownloadPriority::Mixed);
             return;
         }
     }
@@ -120,7 +123,7 @@ void TorrentContentModelFolder::updatePriority()
     setPriority(prio);
 }
 
-void TorrentContentModelFolder::setPriority(BitTorrent::FilePriority newPriority, bool updateParent)
+void TorrentContentModelFolder::setPriority(BitTorrent::DownloadPriority newPriority, bool updateParent)
 {
     if (m_priority == newPriority)
         return;
@@ -132,7 +135,7 @@ void TorrentContentModelFolder::setPriority(BitTorrent::FilePriority newPriority
         m_parentItem->updatePriority();
 
     // Update children
-    if (m_priority != BitTorrent::FilePriority::Mixed)
+    if (m_priority != BitTorrent::DownloadPriority::Mixed)
         for (TorrentContentModelItem *child : asConst(m_childItems))
             child->setPriority(m_priority, false);
 }
@@ -143,7 +146,7 @@ void TorrentContentModelFolder::recalculateProgress()
     qulonglong tSize = 0;
     qulonglong tRemaining = 0;
     for (TorrentContentModelItem *child : asConst(m_childItems)) {
-        if (child->priority() == BitTorrent::FilePriority::Ignored)
+        if (child->priority() == BitTorrent::DownloadPriority::Ignored)
             continue;
 
         if (child->itemType() == FolderType)
@@ -166,7 +169,7 @@ void TorrentContentModelFolder::recalculateAvailability()
     qulonglong tSize = 0;
     bool foundAnyData = false;
     for (TorrentContentModelItem *child : asConst(m_childItems)) {
-        if (child->priority() == BitTorrent::FilePriority::Ignored)
+        if (child->priority() == BitTorrent::DownloadPriority::Ignored)
             continue;
 
         if (child->itemType() == FolderType)
