@@ -29,17 +29,21 @@
 #ifndef TORRENTCONTENTMODELFOLDER_H
 #define TORRENTCONTENTMODELFOLDER_H
 
-#include "base/bittorrent/filepriority.h"
 #include "torrentcontentmodelitem.h"
 
-class TorrentContentModelFolder : public TorrentContentModelItem
+namespace BitTorrent
+{
+    enum class DownloadPriority;
+}
+
+class TorrentContentModelFolder final : public TorrentContentModelItem
 {
 public:
     // Folder constructor
     TorrentContentModelFolder(const QString &name, TorrentContentModelFolder *parent);
 
     // Invisible root item constructor
-    TorrentContentModelFolder(const QList<QVariant> &data);
+    explicit TorrentContentModelFolder(const QVector<QVariant> &data);
 
     ~TorrentContentModelFolder() override;
 
@@ -50,17 +54,17 @@ public:
     void recalculateAvailability();
     void updatePriority();
 
-    void setPriority(BitTorrent::FilePriority newPriority, bool updateParent = true) override;
+    void setPriority(BitTorrent::DownloadPriority newPriority, bool updateParent = true) override;
 
     void deleteAllChildren();
-    const QList<TorrentContentModelItem*> &children() const;
+    const QVector<TorrentContentModelItem*> &children() const;
     void appendChild(TorrentContentModelItem *item);
     TorrentContentModelItem *child(int row) const;
     TorrentContentModelFolder *childFolderWithName(const QString &name) const;
     int childCount() const;
 
 private:
-    QList<TorrentContentModelItem*> m_childItems;
+    QVector<TorrentContentModelItem*> m_childItems;
 };
 
 #endif // TORRENTCONTENTMODELFOLDER_H
