@@ -29,10 +29,11 @@
 #ifndef TORRENTCONTENTMODELITEM_H
 #define TORRENTCONTENTMODELITEM_H
 
-#include <QList>
-#include <QVariant>
+#include <QVector>
 
-#include "base/bittorrent/filepriority.h"
+#include "base/bittorrent/downloadpriority.h"
+
+class QVariant;
 
 class TorrentContentModelFolder;
 
@@ -56,7 +57,7 @@ public:
         FolderType
     };
 
-    TorrentContentModelItem(TorrentContentModelFolder *parent);
+    explicit TorrentContentModelItem(TorrentContentModelFolder *parent);
     virtual ~TorrentContentModelItem();
 
     bool isRootItem() const;
@@ -72,8 +73,8 @@ public:
 
     qreal availability() const;
 
-    BitTorrent::FilePriority priority() const;
-    virtual void setPriority(BitTorrent::FilePriority newPriority, bool updateParent = true) = 0;
+    BitTorrent::DownloadPriority priority() const;
+    virtual void setPriority(BitTorrent::DownloadPriority newPriority, bool updateParent = true) = 0;
 
     int columnCount() const;
     QVariant data(int column) const;
@@ -82,12 +83,12 @@ public:
 protected:
     TorrentContentModelFolder *m_parentItem;
     // Root item members
-    QList<QVariant> m_itemData;
+    QVector<QVariant> m_itemData;
     // Non-root item members
     QString m_name;
     qulonglong m_size;
     qulonglong m_remaining;
-    BitTorrent::FilePriority m_priority;
+    BitTorrent::DownloadPriority m_priority;
     qreal m_progress;
     qreal m_availability;
 };
