@@ -28,9 +28,10 @@
 
 #pragma once
 
-#include <QString>
 #include <QVariant>
 
+class QString;
+
 struct ISession
 {
     virtual ~ISession() = default;
