@@ -29,10 +29,6 @@
 #include "webapplication.h"
 
 #include <algorithm>
-#include <functional>
-#include <queue>
-#include <stdexcept>
-#include <vector>
 
 #include <QDateTime>
 #include <QDebug>
@@ -41,12 +37,13 @@
 #include <QJsonDocument>
 #include <QMimeDatabase>
 #include <QMimeType>
+#include <QNetworkCookie>
 #include <QRegExp>
 #include <QUrl>
 
+#include "base/algorithm.h"
 #include "base/global.h"
 #include "base/http/httperror.h"
-#include "base/iconprovider.h"
 #include "base/logger.h"
 #include "base/preferences.h"
 #include "base/utils/bytearray.h"
@@ -91,10 +88,10 @@ namespace
         return ret;
     }
 
-    inline QUrl urlFromHostHeader(const QString &hostHeader)
+    QUrl urlFromHostHeader(const QString &hostHeader)
     {
         if (!hostHeader.contains(QLatin1String("://")))
-            return QUrl(QLatin1String("http://") + hostHeader);
+            return {QLatin1String("http://") + hostHeader};
         return hostHeader;
     }
 
@@ -117,6 +114,7 @@ namespace
 
 WebApplication::WebApplication(QObject *parent)
     : QObject(parent)
+    , m_cacheID {QString::number(Utils::Random::rand(), 36)}
 {
     registerAPIController(QLatin1String("app"), new AppController(this, this));
     registerAPIController(QLatin1String("auth"), new AuthController(this, this));
@@ -156,9 +154,7 @@ void WebApplication::sendWebUIFile()
     const QString path {
         (request().path != QLatin1String("/")
                 ? request().path
-                : (session()
-                   ? QLatin1String("/index.html")
-                   : QLatin1String("/login.html")))
+                : QLatin1String("/index.html"))
     };
 
     QString localPath {
@@ -195,7 +191,7 @@ void WebApplication::sendWebUIFile()
     sendFile(localPath);
 }
 
-void WebApplication::translateDocument(QString &data)
+void WebApplication::translateDocument(QString &data) const
 {
     const QRegularExpression regex("QBT_TR\\((([^\\)]|\\)(?!QBT_TR))+)\\)QBT_TR\\[CONTEXT=([a-zA-Z_][a-zA-Z0-9_]*)\\]");
 
@@ -227,7 +223,7 @@ void WebApplication::translateDocument(QString &data)
         }
 
         data.replace(QLatin1String("${LANG}"), m_currentLocale.left(2));
-        data.replace(QLatin1String("${VERSION}"), QBT_VERSION);
+        data.replace(QLatin1String("${CACHEID}"), m_cacheID);
     }
 }
 
@@ -248,165 +244,53 @@ const Http::Environment &WebApplication::env() const
 
 void WebApplication::doProcessRequest()
 {
-    QString scope, action;
+    const QRegularExpressionMatch match = m_apiPathPattern.match(request().path);
+    if (!match.hasMatch()) {
+        sendWebUIFile();
+        return;
+    }
 
-    const auto findAPICall = [&]() -> bool
-    {
-        QRegularExpressionMatch match = m_apiPathPattern.match(request().path);
-        if (!match.hasMatch()) return false;
-
-        action = match.captured(QLatin1String("action"));
-        scope = match.captured(QLatin1String("scope"));
-        return true;
-    };
-
-    const auto findLegacyAPICall = [&]() -> bool
-    {
-        QRegularExpressionMatch match = m_apiLegacyPathPattern.match(request().path);
-        if (!match.hasMatch()) return false;
-
-        struct APICompatInfo
-        {
-            QString scope;
-            QString action;
-            std::function<void ()> convertFunc;
-        };
-        const QMap<QString, APICompatInfo> APICompatMapping {
-            {"sync/maindata", {"sync", "maindata", nullptr}},
-            {"sync/torrent_peers", {"sync", "torrentPeers", nullptr}},
-
-            {"login", {"auth", "login", nullptr}},
-            {"logout", {"auth", "logout", nullptr}},
-
-            {"command/shutdown", {"app", "shutdown", nullptr}},
-            {"query/preferences", {"app", "preferences", nullptr}},
-            {"command/setPreferences", {"app", "setPreferences", nullptr}},
-            {"command/getSavePath", {"app", "defaultSavePath", nullptr}},
-
-            {"query/getLog", {"log", "main", nullptr}},
-            {"query/getPeerLog", {"log", "peers", nullptr}},
-
-            {"query/torrents", {"torrents", "info", nullptr}},
-            {"query/propertiesGeneral", {"torrents", "properties", nullptr}},
-            {"query/propertiesTrackers", {"torrents", "trackers", nullptr}},
-            {"query/propertiesWebSeeds", {"torrents", "webseeds", nullptr}},
-            {"query/propertiesFiles", {"torrents", "files", nullptr}},
-            {"query/getPieceHashes", {"torrents", "pieceHashes", nullptr}},
-            {"query/getPieceStates", {"torrents", "pieceStates", nullptr}},
-            {"command/resume", {"torrents", "resume", [this]() { m_params["hashes"] = m_params.take("hash"); }}},
-            {"command/pause", {"torrents", "pause", [this]() { m_params["hashes"] = m_params.take("hash"); }}},
-            {"command/recheck", {"torrents", "recheck", [this]() { m_params["hashes"] = m_params.take("hash"); }}},
-            {"command/resumeAll", {"torrents", "resume", [this]() { m_params["hashes"] = "all"; }}},
-            {"command/pauseAll", {"torrents", "pause", [this]() { m_params["hashes"] = "all"; }}},
-            {"command/rename", {"torrents", "rename", nullptr}},
-            {"command/download", {"torrents", "add", nullptr}},
-            {"command/upload", {"torrents", "add", nullptr}},
-            {"command/delete", {"torrents", "delete", [this]() { m_params["deleteFiles"] = "false"; }}},
-            {"command/deletePerm", {"torrents", "delete", [this]() { m_params["deleteFiles"] = "true"; }}},
-            {"command/addTrackers", {"torrents", "addTrackers", nullptr}},
-            {"command/setFilePrio", {"torrents", "filePrio", nullptr}},
-            {"command/setCategory", {"torrents", "setCategory", nullptr}},
-            {"command/addCategory", {"torrents", "createCategory", nullptr}},
-            {"command/removeCategories", {"torrents", "removeCategories", nullptr}},
-            {"command/getTorrentsUpLimit", {"torrents", "uploadLimit", nullptr}},
-            {"command/getTorrentsDlLimit", {"torrents", "downloadLimit", nullptr}},
-            {"command/setTorrentsUpLimit", {"torrents", "setUploadLimit", nullptr}},
-            {"command/setTorrentsDlLimit", {"torrents", "setDownloadLimit", nullptr}},
-            {"command/increasePrio", {"torrents", "increasePrio", nullptr}},
-            {"command/decreasePrio", {"torrents", "decreasePrio", nullptr}},
-            {"command/topPrio", {"torrents", "topPrio", nullptr}},
-            {"command/bottomPrio", {"torrents", "bottomPrio", nullptr}},
-            {"command/setLocation", {"torrents", "setLocation", nullptr}},
-            {"command/setAutoTMM", {"torrents", "setAutoManagement", nullptr}},
-            {"command/setSuperSeeding", {"torrents", "setSuperSeeding", nullptr}},
-            {"command/setForceStart", {"torrents", "setForceStart", nullptr}},
-            {"command/toggleSequentialDownload", {"torrents", "toggleSequentialDownload", nullptr}},
-            {"command/toggleFirstLastPiecePrio", {"torrents", "toggleFirstLastPiecePrio", nullptr}},
-
-            {"query/transferInfo", {"transfer", "info", nullptr}},
-            {"command/alternativeSpeedLimitsEnabled", {"transfer", "speedLimitsMode", nullptr}},
-            {"command/toggleAlternativeSpeedLimits", {"transfer", "toggleSpeedLimitsMode", nullptr}},
-            {"command/getGlobalUpLimit", {"transfer", "uploadLimit", nullptr}},
-            {"command/getGlobalDlLimit", {"transfer", "downloadLimit", nullptr}},
-            {"command/setGlobalUpLimit", {"transfer", "setUploadLimit", nullptr}},
-            {"command/setGlobalDlLimit", {"transfer", "setDownloadLimit", nullptr}}
-        };
-
-        const QString legacyAction {match.captured(QLatin1String("action"))};
-        const APICompatInfo compatInfo = APICompatMapping.value(legacyAction);
-
-        scope = compatInfo.scope;
-        action = compatInfo.action;
-        if (compatInfo.convertFunc)
-            compatInfo.convertFunc();
-
-        const QString hash {match.captured(QLatin1String("hash"))};
-        if (!hash.isEmpty())
-            m_params[QLatin1String("hash")] = hash;
-
-        return true;
-    };
-
-    if (!findAPICall())
-        findLegacyAPICall();
+    const QString action = match.captured(QLatin1String("action"));
+    const QString scope = match.captured(QLatin1String("scope"));
 
     APIController *controller = m_apiControllers.value(scope);
-    if (!controller) {
-        if (request().path == QLatin1String("/version/api")) {
-            print(QString::number(COMPAT_API_VERSION), Http::CONTENT_TYPE_TXT);
-            return;
-        }
+    if (!controller)
+        throw NotFoundHTTPError();
 
-        if (request().path == QLatin1String("/version/api_min")) {
-            print(QString::number(COMPAT_API_VERSION_MIN), Http::CONTENT_TYPE_TXT);
-            return;
-        }
+    if (!session() && !isPublicAPI(scope, action))
+        throw ForbiddenHTTPError();
 
-        if (request().path == QLatin1String("/version/qbittorrent")) {
-            print(QString(QBT_VERSION), Http::CONTENT_TYPE_TXT);
-            return;
-        }
+    DataMap data;
+    for (const Http::UploadedFile &torrent : request().files)
+        data[torrent.filename] = torrent.data;
 
-        sendWebUIFile();
+    try {
+        const QVariant result = controller->run(action, m_params, data);
+        switch (result.userType()) {
+        case QMetaType::QJsonDocument:
+            print(result.toJsonDocument().toJson(QJsonDocument::Compact), Http::CONTENT_TYPE_JSON);
+            break;
+        case QMetaType::QString:
+        default:
+            print(result.toString(), Http::CONTENT_TYPE_TXT);
+            break;
+        }
     }
-    else {
-        if (!session() && !isPublicAPI(scope, action))
-            throw ForbiddenHTTPError();
-
-        DataMap data;
-        for (const Http::UploadedFile &torrent : request().files)
-            data[torrent.filename] = torrent.data;
-
-        try {
-            const QVariant result = controller->run(action, m_params, data);
-            switch (result.userType()) {
-            case QMetaType::QString:
-                print(result.toString(), Http::CONTENT_TYPE_TXT);
-                break;
-            case QMetaType::QJsonDocument:
-                print(result.toJsonDocument().toJson(QJsonDocument::Compact), Http::CONTENT_TYPE_JSON);
-                break;
-            default:
-                print(result.toString(), Http::CONTENT_TYPE_TXT);
-                break;
-            }
-        }
-        catch (const APIError &error) {
-            // re-throw as HTTPError
-            switch (error.type()) {
-            case APIErrorType::AccessDenied:
-                throw ForbiddenHTTPError(error.message());
-            case APIErrorType::BadData:
-                throw UnsupportedMediaTypeHTTPError(error.message());
-            case APIErrorType::BadParams:
-                throw BadRequestHTTPError(error.message());
-            case APIErrorType::Conflict:
-                throw ConflictHTTPError(error.message());
-            case APIErrorType::NotFound:
-                throw NotFoundHTTPError(error.message());
-            default:
-                Q_ASSERT(false);
-            }
+    catch (const APIError &error) {
+        // re-throw as HTTPError
+        switch (error.type()) {
+        case APIErrorType::AccessDenied:
+            throw ForbiddenHTTPError(error.message());
+        case APIErrorType::BadData:
+            throw UnsupportedMediaTypeHTTPError(error.message());
+        case APIErrorType::BadParams:
+            throw BadRequestHTTPError(error.message());
+        case APIErrorType::Conflict:
+            throw ConflictHTTPError(error.message());
+        case APIErrorType::NotFound:
+            throw NotFoundHTTPError(error.message());
+        default:
+            Q_ASSERT(false);
         }
     }
 }
@@ -446,12 +330,14 @@ void WebApplication::configure()
     m_isLocalAuthEnabled = pref->isWebUiLocalAuthEnabled();
     m_isAuthSubnetWhitelistEnabled = pref->isWebUiAuthSubnetWhitelistEnabled();
     m_authSubnetWhitelist = pref->getWebUiAuthSubnetWhitelist();
+    m_sessionTimeout = pref->getWebUISessionTimeout();
 
     m_domainList = pref->getServerDomains().split(';', QString::SkipEmptyParts);
     std::for_each(m_domainList.begin(), m_domainList.end(), [](QString &entry) { entry = entry.trimmed(); });
 
     m_isClickjackingProtectionEnabled = pref->isWebUiClickjackingProtectionEnabled();
     m_isCSRFProtectionEnabled = pref->isWebUiCSRFProtectionEnabled();
+    m_isSecureCookieEnabled = pref->isWebUiSecureCookieEnabled();
     m_isHostHeaderValidationEnabled = pref->isWebUIHostHeaderValidationEnabled();
     m_isHttpsEnabled = pref->isWebUiHttpsEnabled();
 
@@ -461,6 +347,27 @@ void WebApplication::configure()
             : QLatin1String("default-src 'self'; style-src 'self' 'unsafe-inline'; img-src 'self' data:; script-src 'self' 'unsafe-inline'; object-src 'none'; form-action 'self';"))
         + (m_isClickjackingProtectionEnabled ? QLatin1String(" frame-ancestors 'self';") : QLatin1String(""))
         + (m_isHttpsEnabled ? QLatin1String(" upgrade-insecure-requests;") : QLatin1String(""));
+
+    m_useCustomHTTPHeaders = pref->isWebUICustomHTTPHeadersEnabled();
+    m_customHTTPHeaders.clear();
+    if (m_useCustomHTTPHeaders) {
+        const QString customHeaders = pref->getWebUICustomHTTPHeaders().trimmed();
+        const QVector<QStringRef> customHeaderLines = customHeaders.splitRef('\n', QString::SkipEmptyParts);
+        m_customHTTPHeaders.reserve(customHeaderLines.size());
+
+        for (const QStringRef &line : customHeaderLines) {
+            const int idx = line.indexOf(':');
+            if (idx < 0) {
+                // require separator `:` to be present even if `value` field can be empty
+                LogMsg(tr("Missing ':' separator in WebUI custom HTTP header: \"%1\"").arg(line.toString()), Log::WARNING);
+                continue;
+            }
+
+            const QString header = line.left(idx).trimmed().toString();
+            const QString value = line.mid(idx + 1).trimmed().toString();
+            m_customHTTPHeaders.push_back({header, value});
+        }
+    }
 }
 
 void WebApplication::registerAPIController(const QString &scope, APIController *controller)
@@ -481,11 +388,10 @@ void WebApplication::sendFile(const QString &path)
     const QDateTime lastModified {QFileInfo(path).lastModified()};
 
     // find translated file in cache
-    auto it = m_translatedFiles.constFind(path);
-    if ((it != m_translatedFiles.constEnd()) && (lastModified <= (*it).lastModified)) {
-        const QString mimeName {QMimeDatabase().mimeTypeForFileNameAndData(path, (*it).data).name()};
-        print((*it).data, mimeName);
-        header(Http::HEADER_CACHE_CONTROL, getCachingInterval(mimeName));
+    const auto it = m_translatedFiles.constFind(path);
+    if ((it != m_translatedFiles.constEnd()) && (lastModified <= it->lastModified)) {
+        print(it->data, it->mimeType);
+        header(Http::HEADER_CACHE_CONTROL, getCachingInterval(it->mimeType));
         return;
     }
 
@@ -513,7 +419,7 @@ void WebApplication::sendFile(const QString &path)
         translateDocument(dataStr);
         data = dataStr.toUtf8();
 
-        m_translatedFiles[path] = {data, lastModified}; // caching translated file
+        m_translatedFiles[path] = {data, mimeType.name(), lastModified}; // caching translated file
     }
 
     print(data, mimeType.name());
@@ -566,6 +472,11 @@ Http::Response WebApplication::processRequest(const Http::Request &request, cons
     if (!m_contentSecurityPolicy.isEmpty())
         header(QLatin1String(Http::HEADER_CONTENT_SECURITY_POLICY), m_contentSecurityPolicy);
 
+    if (m_useCustomHTTPHeaders) {
+        for (const CustomHTTPHeader &customHeader : asConst(m_customHTTPHeaders))
+            header(customHeader.name, customHeader.value);
+    }
+
     return response();
 }
 
@@ -585,8 +496,7 @@ void WebApplication::sessionInitialize()
     if (!sessionId.isEmpty()) {
         m_currentSession = m_sessions.value(sessionId);
         if (m_currentSession) {
-            const qint64 now = QDateTime::currentMSecsSinceEpoch() / 1000;
-            if ((now - m_currentSession->m_timestamp) > INACTIVE_TIME) {
+            if (m_currentSession->hasExpired(m_sessionTimeout)) {
                 // session is outdated - removing it
                 delete m_sessions.take(sessionId);
                 m_currentSession = nullptr;
@@ -609,13 +519,9 @@ QString WebApplication::generateSid() const
     QString sid;
 
     do {
-        const size_t size = 6;
-        quint32 tmp[size];
-
-        for (size_t i = 0; i < size; ++i)
-            tmp[i] = Utils::Random::rand();
-
-        sid = QByteArray::fromRawData(reinterpret_cast<const char *>(tmp), sizeof(quint32) * size).toBase64();
+        const quint32 tmp[] = {Utils::Random::rand(), Utils::Random::rand(), Utils::Random::rand()
+                , Utils::Random::rand(), Utils::Random::rand(), Utils::Random::rand()};
+        sid = QByteArray::fromRawData(reinterpret_cast<const char *>(tmp), sizeof(tmp)).toBase64();
     }
     while (m_sessions.contains(sid));
 
@@ -641,18 +547,22 @@ void WebApplication::sessionStart()
     Q_ASSERT(!m_currentSession);
 
     // remove outdated sessions
-    const qint64 now = QDateTime::currentMSecsSinceEpoch() / 1000;
-    const QMap<QString, WebSession *> sessionsCopy {m_sessions};
-    for (const auto session : sessionsCopy) {
-        if ((now - session->timestamp()) > INACTIVE_TIME)
-            delete m_sessions.take(session->id());
-    }
+    Algorithm::removeIf(m_sessions, [this](const QString &, const WebSession *session)
+    {
+        if (session->hasExpired(m_sessionTimeout)) {
+            delete session;
+            return true;
+        }
+
+        return false;
+    });
 
     m_currentSession = new WebSession(generateSid());
     m_sessions[m_currentSession->id()] = m_currentSession;
 
     QNetworkCookie cookie(C_SID, m_currentSession->id().toUtf8());
     cookie.setHttpOnly(true);
+    cookie.setSecure(m_isSecureCookieEnabled && m_isHttpsEnabled);
     cookie.setPath(QLatin1String("/"));
     QByteArray cookieRawForm = cookie.toRawForm();
     if (m_isCSRFProtectionEnabled)
@@ -734,19 +644,7 @@ bool WebApplication::validateHostHeader(const QStringList &domains) const
     }
 
     // try matching host header with local address
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 8, 0))
     const bool sameAddr = m_env.localAddress.isEqual(QHostAddress(requestHost));
-#else
-    const auto equal = [](const Q_IPV6ADDR &l, const Q_IPV6ADDR &r) -> bool
-    {
-        for (int i = 0; i < 16; ++i) {
-            if (l[i] != r[i])
-                return false;
-        }
-        return true;
-    };
-    const bool sameAddr = equal(m_env.localAddress.toIPv6Address(), QHostAddress(requestHost).toIPv6Address());
-#endif
 
     if (sameAddr)
         return true;
@@ -777,9 +675,16 @@ QString WebSession::id() const
     return m_sid;
 }
 
-qint64 WebSession::timestamp() const
+bool WebSession::hasExpired(const qint64 seconds) const
 {
-    return m_timestamp;
+    if (seconds <= 0)
+        return false;
+    return m_timer.hasExpired(seconds * 1000);
+}
+
+void WebSession::updateTimestamp()
+{
+    m_timer.start();
 }
 
 QVariant WebSession::getData(const QString &id) const
@@ -791,8 +696,3 @@ void WebSession::setData(const QString &id, const QVariant &data)
 {
     m_data[id] = data;
 }
-
-void WebSession::updateTimestamp()
-{
-    m_timestamp = QDateTime::currentMSecsSinceEpoch() / 1000;
-}
