@@ -35,6 +35,8 @@ let serverSyncMainDataInterval = 1500;
 let customSyncMainDataInterval = null;
 let searchTabInitialized = false;
 
+let syncRequestInProgress = false;
+
 let clipboardEvent;
 
 const CATEGORIES_ALL = 1;
@@ -182,6 +184,9 @@ window.addEvent('load', function() {
         $("resumed_filter").removeClass("selectedFilter");
         $("active_filter").removeClass("selectedFilter");
         $("inactive_filter").removeClass("selectedFilter");
+        $("stalled_filter").removeClass("selectedFilter");
+        $("stalled_uploading_filter").removeClass("selectedFilter");
+        $("stalled_downloading_filter").removeClass("selectedFilter");
         $("errored_filter").removeClass("selectedFilter");
         $(f + "_filter").addClass("selectedFilter");
         selected_filter = f;
@@ -342,6 +347,9 @@ window.addEvent('load', function() {
         updateFilter('paused', 'QBT_TR(Paused (%1))QBT_TR[CONTEXT=StatusFilterWidget]');
         updateFilter('active', 'QBT_TR(Active (%1))QBT_TR[CONTEXT=StatusFilterWidget]');
         updateFilter('inactive', 'QBT_TR(Inactive (%1))QBT_TR[CONTEXT=StatusFilterWidget]');
+        updateFilter('stalled', 'QBT_TR(Stalled (%1))QBT_TR[CONTEXT=StatusFilterWidget]');
+        updateFilter('stalled_uploading', 'QBT_TR(Stalled Uploading (%1))QBT_TR[CONTEXT=StatusFilterWidget]');
+        updateFilter('stalled_downloading', 'QBT_TR(Stalled Downloading (%1))QBT_TR[CONTEXT=StatusFilterWidget]');
         updateFilter('errored', 'QBT_TR(Errored (%1))QBT_TR[CONTEXT=StatusFilterWidget]');
     };
 
@@ -458,7 +466,7 @@ window.addEvent('load', function() {
     const syncMainData = function() {
         const url = new URI('api/v2/sync/maindata');
         url.setData('rid', syncMainDataLastResponseId);
-        new Request.JSON({
+        const request = new Request.JSON({
             url: url,
             noCache: true,
             method: 'get',
@@ -466,8 +474,8 @@ window.addEvent('load', function() {
                 const errorDiv = $('error_div');
                 if (errorDiv)
                     errorDiv.set('html', 'QBT_TR(qBittorrent client is not reachable)QBT_TR[CONTEXT=HttpServer]');
-                clearTimeout(syncMainDataTimer);
-                syncMainDataTimer = syncMainData.delay(2000);
+                syncRequestInProgress = false;
+                syncData(2000);
             },
             onSuccess: function(response) {
                 $('error_div').set('html', '');
@@ -579,16 +587,24 @@ window.addEvent('load', function() {
                         // re-select previously selected rows
                         torrentsTable.reselectRows(torrentsTableSelectedRows);
                 }
-                clearTimeout(syncMainDataTimer);
-                syncMainDataTimer = syncMainData.delay(getSyncMainDataInterval());
+                syncRequestInProgress = false;
+                syncData(getSyncMainDataInterval());
             }
-        }).send();
+        });
+        syncRequestInProgress = true;
+        request.send();
     };
 
     updateMainData = function() {
         torrentsTable.updateTable();
-        clearTimeout(syncMainDataTimer);
-        syncMainDataTimer = syncMainData.delay(100);
+        syncData(100);
+    };
+
+    const syncData = function(delay) {
+        if (!syncRequestInProgress){
+            clearTimeout(syncMainDataTimer);
+            syncMainDataTimer = syncMainData.delay(delay);
+        }
     };
 
     const processServerState = function() {
@@ -612,7 +628,7 @@ window.addEvent('load', function() {
         $('DHTNodes').set('html', 'QBT_TR(DHT: %1 nodes)QBT_TR[CONTEXT=StatusBar]'.replace("%1", serverState.dht_nodes));
 
         // Statistics dialog
-        if (document.getElementById("statisticspage")) {
+        if (document.getElementById("statisticsContent")) {
             $('AlltimeDL').set('html', window.qBittorrent.Misc.friendlyUnit(serverState.alltime_dl, false));
             $('AlltimeUL').set('html', window.qBittorrent.Misc.friendlyUnit(serverState.alltime_ul, false));
             $('TotalWastedSession').set('html', window.qBittorrent.Misc.friendlyUnit(serverState.total_wasted_session, false));
@@ -627,12 +643,23 @@ window.addEvent('load', function() {
             $('TotalQueuedSize').set('html', window.qBittorrent.Misc.friendlyUnit(serverState.total_queued_size, false));
         }
 
-        if (serverState.connection_status == "connected")
-            $('connectionStatus').src = 'images/skin/connected.svg';
-        else if (serverState.connection_status == "firewalled")
-            $('connectionStatus').src = 'images/skin/firewalled.svg';
-        else
-            $('connectionStatus').src = 'images/skin/disconnected.svg';
+        switch (serverState.connection_status) {
+        case 'connected': {
+                $('connectionStatus').src = 'images/skin/connected.svg';
+                $('connectionStatus').alt = 'QBT_TR(Connection status: Connected)QBT_TR[CONTEXT=MainWindow]';
+            }
+            break;
+        case 'firewalled': {
+                $('connectionStatus').src = 'images/skin/firewalled.svg';
+                $('connectionStatus').alt = 'QBT_TR(Connection status: Firewalled)QBT_TR[CONTEXT=MainWindow]';
+            }
+            break;
+        default: {
+                $('connectionStatus').src = 'images/skin/disconnected.svg';
+                $('connectionStatus').alt = 'QBT_TR(Connection status: Disconnected)QBT_TR[CONTEXT=MainWindow]';    
+            }
+            break;
+        }  
 
         if (queueing_enabled != serverState.queueing) {
             queueing_enabled = serverState.queueing;
@@ -665,10 +692,14 @@ window.addEvent('load', function() {
     };
 
     const updateAltSpeedIcon = function(enabled) {
-        if (enabled)
-            $('alternativeSpeedLimits').src = "images/slow.svg";
-        else
-            $('alternativeSpeedLimits').src = "images/slow_off.svg";
+        if (enabled) {
+            $('alternativeSpeedLimits').src = 'images/slow.svg';
+            $('alternativeSpeedLimits').alt = 'QBT_TR(Alternative speed limits: On)QBT_TR[CONTEXT=MainWindow]';
+        }        
+        else {
+            $('alternativeSpeedLimits').src = 'images/slow_off.svg';
+            $('alternativeSpeedLimits').alt = 'QBT_TR(Alternative speed limits: Off)QBT_TR[CONTEXT=MainWindow]';
+        }
     };
 
     $('alternativeSpeedLimits').addEvent('click', function() {
@@ -764,8 +795,7 @@ window.addEvent('load', function() {
         $("mainColumn").removeClass("invisible");
 
         customSyncMainDataInterval = null;
-        clearTimeout(syncMainDataTimer);
-        syncMainDataTimer = syncMainData.delay(100);
+        syncData(100);
 
         hideSearchTab();
     };
@@ -967,7 +997,10 @@ window.addEvent('load', function() {
 
 function registerMagnetHandler() {
     if (typeof navigator.registerProtocolHandler !== 'function') {
-        alert("Your browser does not support this feature");
+        if (window.location.protocol !== 'https:')
+            alert("QBT_TR(To use this feature, the WebUI needs to be accessed over HTTPS)QBT_TR[CONTEXT=MainWindow]");
+        else
+            alert("QBT_TR(Your browser does not support this feature)QBT_TR[CONTEXT=MainWindow]");
         return;
     }
 
