@@ -1094,10 +1094,6 @@ Si us plau, no useu cap caràcter especial al nom de la categoria.</translation>
         <source>Info: The password is saved unencrypted</source>
         <translation>Informació: la contrasenya es desa sense encriptar.</translation>
     </message>
-    <message>
-        <source>Strict super seeding:</source>
-        <translation type="vanished">Supersembra estricta:</translation>
-    </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
         <translation>Algorisme de mode mesclat uTP-TCP:</translation>
@@ -1334,6 +1330,14 @@ Si us plau, no useu cap caràcter especial al nom de la categoria.</translation>
         <source>UPnP lease duration [0: Permanent lease]:</source>
         <translation>Durada de la cessió d'UPnP [0: cessió permanent]:</translation>
     </message>
+    <message>
+        <source>Header: value pairs, one per line</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Add custom HTTP headers</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PeerListWidget</name>
