@@ -1094,10 +1094,6 @@ Assicurati che corrispondano allo standard IP:porta.</translation>
         <source>Info: The password is saved unencrypted</source>
         <translation>Info: la password è salvata non criptata</translation>
     </message>
-    <message>
-        <source>Strict super seeding:</source>
-        <translation type="vanished">Super seeding rigoroso:</translation>
-    </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
         <translation>Algoritmo modo misto μTP-TC:</translation>
@@ -1334,6 +1330,14 @@ Assicurati che corrispondano allo standard IP:porta.</translation>
         <source>UPnP lease duration [0: Permanent lease]:</source>
         <translation>Durata lease UPNP [0: lease permanente]:</translation>
     </message>
+    <message>
+        <source>Header: value pairs, one per line</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Add custom HTTP headers</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PeerListWidget</name>
