@@ -1093,10 +1093,6 @@
         <source>Info: The password is saved unencrypted</source>
         <translation>Informação: A palavra-passe é guardada sem encriptação</translation>
     </message>
-    <message>
-        <source>Strict super seeding:</source>
-        <translation type="vanished">Restringir super semear:</translation>
-    </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
         <translation>Algoritmo do modo de mistura uTP-TCP:</translation>
@@ -1333,6 +1329,14 @@
         <source>UPnP lease duration [0: Permanent lease]:</source>
         <translation>Duração da concessão [0: Concessão permanente]:</translation>
     </message>
+    <message>
+        <source>Header: value pairs, one per line</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Add custom HTTP headers</source>
+        <translation type="unfinished" />
+    </message>
 </context>
 <context>
     <name>PeerListWidget</name>
