@@ -348,6 +348,18 @@
         <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
         <translation>JavaScript Krävs! Du måste aktivera JavaScript för att webbgränssnittet ska fungera korrekt</translation>
     </message>
+    <message>
+        <source>Name cannot be empty</source>
+        <translation>Namnet kan inte vara tomt</translation>
+    </message>
+    <message>
+        <source>Name is unchanged</source>
+        <translation>Namnet är oförändrat</translation>
+    </message>
+    <message>
+        <source>Failed to update name</source>
+        <translation>Det gick inte att uppdatera namnet</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -508,6 +520,46 @@
         <source>Move to the top of the queue</source>
         <translation>Flytta till början av kön</translation>
     </message>
+    <message>
+        <source>Your browser does not support this feature</source>
+        <translation>Din webbläsare stöder inte den här funktionen</translation>
+    </message>
+    <message>
+        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
+        <translation>För att använda den här funktionen måste WebUI nås via HTTPS</translation>
+    </message>
+    <message>
+        <source>Connection status: Firewalled</source>
+        <translation>Anslutningsstatus: Bakom brandvägg</translation>
+    </message>
+    <message>
+        <source>Connection status: Connected</source>
+        <translation>Anslutningsstatus: Ansluten</translation>
+    </message>
+    <message>
+        <source>Alternative speed limits: Off</source>
+        <translation>Alternativa hastighetsgränser: Av</translation>
+    </message>
+    <message>
+        <source>Download speed icon</source>
+        <translation>Ikon för hämtningshastighet</translation>
+    </message>
+    <message>
+        <source>Connection status</source>
+        <translation>Anslutningsstatus</translation>
+    </message>
+    <message>
+        <source>Alternative speed limits: On</source>
+        <translation>Alternativa hastighetsgränser: På</translation>
+    </message>
+    <message>
+        <source>Upload speed icon</source>
+        <translation>Ikon för sändningshastighet</translation>
+    </message>
+    <message>
+        <source>Connection status: Disconnected</source>
+        <translation>Anslutningsstatus: Frånkopplad</translation>
+    </message>
 </context>
 <context>
     <name>OptionsDialog</name>
@@ -963,7 +1015,7 @@
     </message>
     <message>
         <source>Do not start the download automatically</source>
-        <translation>Börja inte hämtning automatiskt</translation>
+        <translation>Starta inte hämtningen automatiskt</translation>
     </message>
     <message>
         <source>Switch torrent to Manual Mode</source>
@@ -1041,10 +1093,6 @@
         <source>Info: The password is saved unencrypted</source>
         <translation>Info: Lösenordet sparas okrypterat</translation>
     </message>
-    <message>
-        <source>Strict super seeding:</source>
-        <translation>Strikt superdistribuering:</translation>
-    </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
         <translation>µTP-TCP blandad lägesalgoritm:</translation>
@@ -1085,10 +1133,6 @@
         <source>When ratio reaches</source>
         <translation>När förhållandet når</translation>
     </message>
-    <message>
-        <source>sec</source>
-        <translation>sek</translation>
-    </message>
     <message>
         <source>When seeding time reaches</source>
         <translation>När distribueringstiden når</translation>
@@ -1205,10 +1249,6 @@
         <source>Fixed slots</source>
         <translation>Fasta platser</translation>
     </message>
-    <message>
-        <source>Resolve peer countries (GeoIP):</source>
-        <translation>Slå upp nodernas länder (GeoIP)</translation>
-    </message>
     <message>
         <source>Advanced</source>
         <translation>Avancerat</translation>
@@ -1219,7 +1259,7 @@
     </message>
     <message>
         <source>Upload choking algorithm:</source>
-        <translation type="unfinished" />
+        <translation>Ladda upp strypningsalgoritm:</translation>
     </message>
     <message>
         <source>Seeding Limits</source>
@@ -1262,8 +1302,40 @@
         <translation>Sessionen löpte ut:</translation>
     </message>
     <message>
-        <source>Listen on IPv6 address (requires restart):</source>
-        <translation>Lyssna på IPv6-adress (kräver omstart):</translation>
+        <source>Resolve peer countries:</source>
+        <translation>Slå upp nodernas länder:</translation>
+    </message>
+    <message>
+        <source>ban for:</source>
+        <translation>förbud för:</translation>
+    </message>
+    <message>
+        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
+        <translation>Använd delutsträckningsaffinitet (kräver libtorrent &gt;= 1.2.2):</translation>
+    </message>
+    <message>
+        <source>Stop tracker timeout:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Ban client after consecutive failures:</source>
+        <translation>Förbud mot klient efter påföljande misslyckanden:</translation>
+    </message>
+    <message>
+        <source>Enable cookie Secure flag (requires HTTPS)</source>
+        <translation>Aktivera säker flagga för kakor (kräver HTTPS)</translation>
+    </message>
+    <message>
+        <source>UPnP lease duration [0: Permanent lease]:</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Header: value pairs, one per line</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Add custom HTTP headers</source>
+        <translation type="unfinished" />
     </message>
 </context>
 <context>
@@ -1324,10 +1396,6 @@
         <comment>i.e. files that are being downloaded right now</comment>
         <translation>Filer</translation>
     </message>
-    <message>
-        <source>Country</source>
-        <translation>Land</translation>
-    </message>
     <message>
         <source>Ban peer permanently</source>
         <translation>Förbjud noden permanent</translation>
@@ -1344,6 +1412,10 @@
         <source>Add a new peer...</source>
         <translation>Lägg till en ny nod...</translation>
     </message>
+    <message>
+        <source>Country/Region</source>
+        <translation>Land/Region</translation>
+    </message>
 </context>
 <context>
     <name>PropListDelegate</name>
@@ -1545,6 +1617,10 @@
         <source>Filter files...</source>
         <translation>Filtrera filer...</translation>
     </message>
+    <message>
+        <source>Rename...</source>
+        <translation>Byter namn...</translation>
+    </message>
 </context>
 <context>
     <name>ScanFoldersModel</name>
@@ -1721,6 +1797,30 @@
         <source>Errored (%1)</source>
         <translation>Fallerande (%1)</translation>
     </message>
+    <message>
+        <source>Stalled Uploading (%1)</source>
+        <translation>Avstannade sändningar (%1)</translation>
+    </message>
+    <message>
+        <source>Stalled Downloading (%1)</source>
+        <translation>Avstannade hämtningar (%1)</translation>
+    </message>
+    <message>
+        <source>Stalled Downloading (0)</source>
+        <translation>Avstannade hämtningar (0)</translation>
+    </message>
+    <message>
+        <source>Stalled (0)</source>
+        <translation>Avstannade (0)</translation>
+    </message>
+    <message>
+        <source>Stalled Uploading (0)</source>
+        <translation>Avstannade sändningar (0)</translation>
+    </message>
+    <message>
+        <source>Stalled (%1)</source>
+        <translation>Avstannade (%1)</translation>
+    </message>
 </context>
 <context>
     <name>TorrentContentModel</name>
@@ -1775,7 +1875,7 @@
     <message>
         <source>ETA</source>
         <comment>i.e: Estimated Time of Arrival / Time left</comment>
-        <translation>Slutfört om</translation>
+        <translation>Slutförd om</translation>
     </message>
     <message>
         <source>Category</source>
@@ -2557,6 +2657,14 @@
         <source>Version</source>
         <translation>Version</translation>
     </message>
+    <message>
+        <source>Yes</source>
+        <translation>Ja</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>Nej</translation>
+    </message>
 </context>
 <context>
     <name>PeersAdditionDialog</name>
@@ -2677,10 +2785,6 @@
         <source>About qBittorrent</source>
         <translation>Om qBittorrent</translation>
     </message>
-    <message>
-        <source>Libraries</source>
-        <translation>Bibliotek</translation>
-    </message>
     <message>
         <source>License</source>
         <translation>Licens</translation>
@@ -2701,6 +2805,14 @@
         <source>Author</source>
         <translation>Upphovsmän</translation>
     </message>
+    <message>
+        <source>Software Used</source>
+        <translation>Mjukvara som används</translation>
+    </message>
+    <message>
+        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
+        <translation>Den fria databasen IP to Country Lite av DB-IP används för att slå upp nodernas länder. Databasen är licensierad enligt Creative Commons Attribution 4.0 International License</translation>
+    </message>
 </context>
 <context>
     <name>OptionDialog</name>
@@ -2708,6 +2820,14 @@
         <source>All addresses</source>
         <translation>Alla adresser</translation>
     </message>
+    <message>
+        <source>All IPv6 addresses</source>
+        <translation>Alla IPv6-adresser</translation>
+    </message>
+    <message>
+        <source>All IPv4 addresses</source>
+        <translation>Alla IPv4-adresser</translation>
+    </message>
 </context>
 <context>
     <name>SearchJobWidget</name>
@@ -2736,4 +2856,15 @@
         <translation>Hämtningslänk</translation>
     </message>
 </context>
+<context>
+    <name>TorrentContentTreeView</name>
+    <message>
+        <source>Renaming</source>
+        <translation>Byter namn</translation>
+    </message>
+    <message>
+        <source>New name:</source>
+        <translation>Nytt namn:</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
