@@ -348,6 +348,18 @@
         <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
         <translation>需要 JavaScript！您必須啟用 JavaScript 以讓 WebUI 正常運作</translation>
     </message>
+    <message>
+        <source>Name cannot be empty</source>
+        <translation>名稱不能為空</translation>
+    </message>
+    <message>
+        <source>Name is unchanged</source>
+        <translation>名稱未變更</translation>
+    </message>
+    <message>
+        <source>Failed to update name</source>
+        <translation>更新名稱失敗</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -508,6 +520,46 @@
         <source>Move to the top of the queue</source>
         <translation>移動到佇列頂部</translation>
     </message>
+    <message>
+        <source>Your browser does not support this feature</source>
+        <translation>您的瀏覽器不支援此功能</translation>
+    </message>
+    <message>
+        <source>To use this feature, the WebUI needs to be accessed over HTTPS</source>
+        <translation>要使用此功能，必須透過 HTTPS 存取 WebUI</translation>
+    </message>
+    <message>
+        <source>Connection status: Firewalled</source>
+        <translation>連線狀態：已有防火牆保護</translation>
+    </message>
+    <message>
+        <source>Connection status: Connected</source>
+        <translation>連線狀態：已連線</translation>
+    </message>
+    <message>
+        <source>Alternative speed limits: Off</source>
+        <translation>替代速率限制：關閉</translation>
+    </message>
+    <message>
+        <source>Download speed icon</source>
+        <translation>下載速度圖示</translation>
+    </message>
+    <message>
+        <source>Connection status</source>
+        <translation>連線狀態</translation>
+    </message>
+    <message>
+        <source>Alternative speed limits: On</source>
+        <translation>替代速率限制：開啟</translation>
+    </message>
+    <message>
+        <source>Upload speed icon</source>
+        <translation>上傳速度圖示</translation>
+    </message>
+    <message>
+        <source>Connection status: Disconnected</source>
+        <translation>連線狀態：已斷線</translation>
+    </message>
 </context>
 <context>
     <name>OptionsDialog</name>
@@ -1041,10 +1093,6 @@
         <source>Info: The password is saved unencrypted</source>
         <translation>資訊：密碼以未加密的形式儲存</translation>
     </message>
-    <message>
-        <source>Strict super seeding:</source>
-        <translation>嚴格超級種子</translation>
-    </message>
     <message>
         <source>μTP-TCP mixed mode algorithm:</source>
         <translation>μTP-TCP 混合模式演算法</translation>
@@ -1085,10 +1133,6 @@
         <source>When ratio reaches</source>
         <translation>當分享率達到</translation>
     </message>
-    <message>
-        <source>sec</source>
-        <translation>秒</translation>
-    </message>
     <message>
         <source>When seeding time reaches</source>
         <translation>當做種時間達到</translation>
@@ -1205,10 +1249,6 @@
         <source>Fixed slots</source>
         <translation>固定通道</translation>
     </message>
-    <message>
-        <source>Resolve peer countries (GeoIP):</source>
-        <translation>解析下載者的國家 (GeoIP)：</translation>
-    </message>
     <message>
         <source>Advanced</source>
         <translation>進階</translation>
@@ -1262,8 +1302,40 @@
         <translation>工作階段逾時：</translation>
     </message>
     <message>
-        <source>Listen on IPv6 address (requires restart):</source>
-        <translation>監聽 IPv6 位置（需要重新啟動）：</translation>
+        <source>Resolve peer countries:</source>
+        <translation>解析 peer 國家：</translation>
+    </message>
+    <message>
+        <source>ban for:</source>
+        <translation>封鎖：</translation>
+    </message>
+    <message>
+        <source>Use piece extent affinity (requires libtorrent &gt;= 1.2.2):</source>
+        <translation>使用片段範圍關聯（需要 libtorrent &gt;= 1.2.2）：</translation>
+    </message>
+    <message>
+        <source>Stop tracker timeout:</source>
+        <translation>停止追蹤器逾時：</translation>
+    </message>
+    <message>
+        <source>Ban client after consecutive failures:</source>
+        <translation>連續失敗後封鎖客戶端：</translation>
+    </message>
+    <message>
+        <source>Enable cookie Secure flag (requires HTTPS)</source>
+        <translation>啟用 cookie 安全旗標（需要 HTTPS）</translation>
+    </message>
+    <message>
+        <source>UPnP lease duration [0: Permanent lease]:</source>
+        <translation>UPnP 租約期限 [0：永久租約]：</translation>
+    </message>
+    <message>
+        <source>Header: value pairs, one per line</source>
+        <translation type="unfinished" />
+    </message>
+    <message>
+        <source>Add custom HTTP headers</source>
+        <translation type="unfinished" />
     </message>
 </context>
 <context>
@@ -1324,10 +1396,6 @@
         <comment>i.e. files that are being downloaded right now</comment>
         <translation>檔案</translation>
     </message>
-    <message>
-        <source>Country</source>
-        <translation>國籍</translation>
-    </message>
     <message>
         <source>Ban peer permanently</source>
         <translation>永遠封鎖下載者</translation>
@@ -1344,6 +1412,10 @@
         <source>Add a new peer...</source>
         <translation>新增下載者……</translation>
     </message>
+    <message>
+        <source>Country/Region</source>
+        <translation>國家／區域</translation>
+    </message>
 </context>
 <context>
     <name>PropListDelegate</name>
@@ -1545,6 +1617,10 @@
         <source>Filter files...</source>
         <translation>過濾檔案……</translation>
     </message>
+    <message>
+        <source>Rename...</source>
+        <translation>重新命名……</translation>
+    </message>
 </context>
 <context>
     <name>ScanFoldersModel</name>
@@ -1721,6 +1797,30 @@
         <source>Errored (%1)</source>
         <translation>錯誤 (%1)</translation>
     </message>
+    <message>
+        <source>Stalled Uploading (%1)</source>
+        <translation>停止上傳 (%1)</translation>
+    </message>
+    <message>
+        <source>Stalled Downloading (%1)</source>
+        <translation>停止下載 (%1)</translation>
+    </message>
+    <message>
+        <source>Stalled Downloading (0)</source>
+        <translation>停止下載 (0)</translation>
+    </message>
+    <message>
+        <source>Stalled (0)</source>
+        <translation>停止 (0)</translation>
+    </message>
+    <message>
+        <source>Stalled Uploading (0)</source>
+        <translation>停止上傳 (0)</translation>
+    </message>
+    <message>
+        <source>Stalled (%1)</source>
+        <translation>停止 (%1)</translation>
+    </message>
 </context>
 <context>
     <name>TorrentContentModel</name>
@@ -2557,6 +2657,14 @@
         <source>Version</source>
         <translation>版本</translation>
     </message>
+    <message>
+        <source>Yes</source>
+        <translation>是</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation>否</translation>
+    </message>
 </context>
 <context>
     <name>PeersAdditionDialog</name>
@@ -2677,10 +2785,6 @@
         <source>About qBittorrent</source>
         <translation>關於 qBittorrent</translation>
     </message>
-    <message>
-        <source>Libraries</source>
-        <translation>函式庫</translation>
-    </message>
     <message>
         <source>License</source>
         <translation>授權條款</translation>
@@ -2701,6 +2805,14 @@
         <source>Author</source>
         <translation>作者</translation>
     </message>
+    <message>
+        <source>Software Used</source>
+        <translation>使用的軟體</translation>
+    </message>
+    <message>
+        <source>The free IP to Country Lite database by DB-IP is used for resolving the countries of peers. The database is licensed under the Creative Commons Attribution 4.0 International License</source>
+        <translation>由 DB-IP 提供，用於解析 peer 的所在國家的免費 IP 對國家 Lite 資料庫。此資料庫以創用 CC 姓名標示 4.0 國際授權條款授權</translation>
+    </message>
 </context>
 <context>
     <name>OptionDialog</name>
@@ -2708,6 +2820,14 @@
         <source>All addresses</source>
         <translation>所有位置</translation>
     </message>
+    <message>
+        <source>All IPv6 addresses</source>
+        <translation>所有 IPv6 地址</translation>
+    </message>
+    <message>
+        <source>All IPv4 addresses</source>
+        <translation>所有 IPv4 地址</translation>
+    </message>
 </context>
 <context>
     <name>SearchJobWidget</name>
@@ -2736,4 +2856,15 @@
         <translation>下載連結</translation>
     </message>
 </context>
+<context>
+    <name>TorrentContentTreeView</name>
+    <message>
+        <source>Renaming</source>
+        <translation>正在重新命名</translation>
+    </message>
+    <message>
+        <source>New name:</source>
+        <translation>新名稱：</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
